#
# tclSadie_classifymenu_init --
#
#       Initialize the parameters for the all of the classify menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_classifymenu_init {} {
    levelslice_init
    mindistance_init
    maxlike_init
    cluster_init
    segment_init
    sigmap_init
}



#
# levelslice_dialog --
#
#       Create a dialog box for performing a levelslice classification on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc levelslice_dialog { } {
    global LevelsliceVar
    global confirmStatus

    #
    # Determine the current image
    #
    set LevelsliceVar(inimg,array) [get_current_image]
    if {$LevelsliceVar(inimg,array) != "none"} {
	    upvar #0 $LevelsliceVar(inimg,array) imgarray
	    set LevelsliceVar(inimg,name) $imgarray(title)
	    set LevelsliceVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .levelslicedlg]
    wm geometry $top +110+110
    wm title $top "Levelslice Classification Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a Levelslice Classification on: "
    label $title.imglbl -fg blue -text $LevelsliceVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    create_class_widget $input.classes $LevelsliceVar(inimg,array)
    
    label $input.threshlbl -text "Threshold: "
    entry $input.threshent -width 5 -textvariable LevelsliceVar(thresh)
    label $input.threshunits -text "Standard Deviation(s)"

    grid $input.classes -row 0 -column 0 -columnspan 4 -pady 8 -padx 6 -sticky nw
    grid $input.threshlbl -row 1 -column 0 -sticky w
    grid $input.threshent -row 1 -column 1 -pady 8 -sticky w
    grid $input.threshunits -row 1 -column 2 -sticky w
    grid columnconfigure $input 3 -weight 1 -minsize 80
puts "running update_class_widget"
    update_class_widget $input.classes $LevelsliceVar(inimg,array)
puts "done running update_class_widget"

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable LevelsliceVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus


    if {$confirmStatus == 1} {
        levelslice_run    
    }


    destroy $top
}
#
# levelslice_run --
#
#       Define a new region based on the parameters from the
#       levelslice dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc levelslice_run {} {
    global LevelsliceVar

    upvar #0 $LevelsliceVar(inimg,array) imgarray
    set LevelsliceVar(numclasses) $imgarray(class,count)
    
    set out_sadie_addr [Sadie_Classify_LvlSlice LevelsliceVar]

    create_display_image $LevelsliceVar(outname) $out_sadie_addr
}
#
# levelslice_init --
#
#       Initialize the parameters for the levelslice dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc levelslice_init {} {
    global LevelsliceVar
    
    set LevelsliceVar(inimg,array) "none"
    set LevelsliceVar(inimg,name) "none"
    set LevelsliceVar(inimg,addr) "none"
    set LevelsliceVar(thresh) 4.0
    set LevelsliceVar(outname) "LvlSlice"
}










#
# mindistance_dialog --
#
#       Create a dialog box for performing a minimum distance classification on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc mindistance_dialog { } {
    global MindistanceVar
    global confirmStatus

    #
    # Determine the current image
    #
    set MindistanceVar(inimg,array) [get_current_image]
    if {$MindistanceVar(inimg,array) != "none"} {
	    upvar #0 $MindistanceVar(inimg,array) imgarray
	    set MindistanceVar(inimg,name) $imgarray(title)
	    set MindistanceVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .mindistancedlg]
    wm geometry $top +110+110
    wm title $top "Minimum Distance Classification Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a Minimum Distance Classification on: "
    label $title.imglbl -fg blue -text $MindistanceVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    create_class_widget $input.classes $MindistanceVar(inimg,array)
    
    label $input.distlbl -text "Distance Measure: "
    tk_optionMenu $input.distbtn MindistanceVar(type) \
	    "City-Block" "Euclidean" "Mahalanobis"

    grid $input.classes -row 0 -column 0 -columnspan 3 -pady 8 -padx 6 -sticky nw
    grid $input.distlbl -row 1 -column 0 -sticky w
    grid $input.distbtn -row 1 -column 1  -columnspan 2 -pady 8 -sticky w
    grid columnconfigure $input 2 -weight 1 -minsize 80

    update_class_widget $input.classes $MindistanceVar(inimg,array)

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable MindistanceVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        mindistance_run    
    }


    destroy $top
}
#
# mindistance_run --
#
#       Define a new region based on the parameters from the
#       mindistance dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc mindistance_run {} {
    global MindistanceVar

    switch $MindistanceVar(type) {
	"City-Block" {set MindistanceVar(option) 0}
	"Euclidean" {set MindistanceVar(option) 1}
	default {set MindistanceVar(option) 2}
    }

    upvar #0 $MindistanceVar(inimg,array) imgarray
    set MindistanceVar(numclasses) $imgarray(class,count)
    
    set out_sadie_addr [Sadie_Classify_MinDist MindistanceVar]

    create_display_image $MindistanceVar(outname) $out_sadie_addr
}
#
# mindistance_init --
#
#       Initialize the parameters for the mindistance dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc mindistance_init {} {
    global MindistanceVar
    
    set MindistanceVar(inimg,array) "none"
    set MindistanceVar(inimg,name) "none"
    set MindistanceVar(inimg,addr) "none"
    set MindistanceVar(type) "City-Block"
    set MindistanceVar(outname) "MinDist"

    set MindistanceVar(value,City-Block) 0
    set MindistanceVar(value,Euclidean) 1
    set MindistanceVar(value,Mahalanobis) 2
}







#
# maxlike_dialog --
#
#       Create a dialog box for performing a maximum likelihood classification on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc maxlike_dialog { } {
    global MaxlikeVar
    global confirmStatus

    #
    # Determine the current image
    #
    set MaxlikeVar(inimg,array) [get_current_image]
    if {$MaxlikeVar(inimg,array) != "none"} {
	    upvar #0 $MaxlikeVar(inimg,array) imgarray
	    set MaxlikeVar(inimg,name) $imgarray(title)
	    set MaxlikeVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .maxlikedlg]
    wm geometry $top +110+110
    wm title $top "Maxlike Classification Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a Maxlike Classification on: "
    label $title.imglbl -fg blue -text $MaxlikeVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    create_class_widget $input.classes $MaxlikeVar(inimg,array)
    
    label $input.problbl -text "Probability: "
    entry $input.probent -width 8 -textvariable MaxlikeVar(prob)

    grid $input.classes -row 0 -column 0 -columnspan 3 -pady 8 -padx 6 -sticky nw
    grid $input.problbl -row 1 -column 0 -sticky w
    grid $input.probent -row 1 -column 1 -pady 8 -sticky w
    grid columnconfigure $input 2 -weight 1 -minsize 180

    update_class_widget $input.classes $MaxlikeVar(inimg,array)

    global $MaxlikeVar(inimg,array)
    trace variable $MaxlikeVar(inimg,array)(class,count) w "maxlike_update_prob $MaxlikeVar(inimg,array)"
    maxlike_update_prob $MaxlikeVar(inimg,array)
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable MaxlikeVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        maxlike_run    
    }


    destroy $top
}
#
# maxlike_run --
#
#       Define a new region based on the parameters from the
#       maxlike dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc maxlike_run {} {
    global MaxlikeVar

    upvar #0 $MaxlikeVar(inimg,array) imgarray
    set MaxlikeVar(numclasses) $imgarray(class,count)
    
    set out_sadie_addr [Sadie_Classify_MaxLike MaxlikeVar]

    create_display_image $MaxlikeVar(outname) $out_sadie_addr
}
#
# maxlike_init --
#
#       Initialize the parameters for the maxlike dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc maxlike_init {} {
    global MaxlikeVar
    
    set MaxlikeVar(inimg,array) "none"
    set MaxlikeVar(inimg,name) "none"
    set MaxlikeVar(inimg,addr) "none"
    set MaxlikeVar(prob) 1.0
    set MaxlikeVar(outname) "MaxLike"
}
proc maxlike_update_prob {arrayName args} {
    global MaxlikeVar
    upvar #0 $arrayName imgarray

    set MaxlikeVar(prob) [format "%.6f" [expr 1.0 / $imgarray(class,count)]]
}




#
# cluster_dialog --
#
#       Create a dialog box for performing a cluster on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc cluster_dialog { } {
    global ClusterVar
    global confirmStatus

    #
    # Determine the current image
    #
    set ClusterVar(inimg,array) [get_current_image]
    if {$ClusterVar(inimg,array) != "none"} {
	    upvar #0 $ClusterVar(inimg,array) imgarray
	    set ClusterVar(inimg,name) $imgarray(title)
	    set ClusterVar(inimg,addr) $imgarray(sadie_addr)
	    set ClusterVar(res) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .clusterdlg]
    wm geometry $top +110+110
    wm title $top "Cluster Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Cluster on: "
    label $title.imglbl -fg blue -text $ClusterVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Number of Iterations: "}
    lappend row {entry ClusterVar(iter)}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Number of Seed Classes: "}
    lappend row {entry ClusterVar(classes)}
    dialog_create_stdrow $input 1 $row
    
    set row {}
    lappend row {label "Minimum Class Size: "}
    lappend row {entry ClusterVar(min)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label "Class Merging Threshold: "}
    lappend row {entry ClusterVar(merging)}
    dialog_create_stdrow $input 3 $row
    
    set row {}
    lappend row {label "Sample Increment: "}
    lappend row {entry ClusterVar(incr)}
    lappend row {label "Line(s) and Pixel(s)"}
    dialog_create_stdrow $input 4 $row
    
    set row {}
    lappend row {label "Outlier Threshold: "}
    lappend row {entry ClusterVar(outlier)}
    dialog_create_stdrow $input 5 $row
    
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ClusterVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        cluster_run    
    }


    destroy $top
}
#
# cluster_run --
#
#       Define a new region based on the parameters from the
#       cluster dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc cluster_run {} {
    global ClusterVar
    
    set out_sadie_addr [Sadie_Classify_Cluster ClusterVar]

    create_display_image $ClusterVar(outname) $out_sadie_addr
}
#
# cluster_init --
#
#       Initialize the parameters for the cluster dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc cluster_init {} {
    global ClusterVar
    
    set ClusterVar(inimg,array) "none"
    set ClusterVar(inimg,name) "none"
    set ClusterVar(inimg,addr) "none"
    set ClusterVar(iter) 5
    set ClusterVar(classes) 10
    set ClusterVar(min) 1
    set ClusterVar(incr) 1
    set ClusterVar(merging) 0.0
    set ClusterVar(outlier) 4.0
    set ClusterVar(outname) "Cluster"
}




#
# segment_dialog --
#
#       Create a dialog box for performing a segment on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc segment_dialog { } {
    global SegmentVar
    global confirmStatus

    #
    # Determine the current image
    #
    set SegmentVar(inimg,array) [get_current_image]
    if {$SegmentVar(inimg,array) != "none"} {
	    upvar #0 $SegmentVar(inimg,array) imgarray
	    set SegmentVar(inimg,name) $imgarray(title)
	    set SegmentVar(inimg,addr) $imgarray(sadie_addr)
	    set SegmentVar(res) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .segmentdlg]
    wm geometry $top +110+110
    wm title $top "Segment Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Segment on: "
    label $title.imglbl -fg blue -text $SegmentVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Graylevel Difference Threshold: " none 2}
    lappend row {entry SegmentVar(thresh)}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Graylevel Variance Threshold: " none 2}
    lappend row {entry SegmentVar(sigma)}
    dialog_create_stdrow $input 1 $row
    
    set row {}
    lappend row {checkbutton "Reduction" SegmentVar(reduction) 1 0 segment_update}
    lappend row {label "    Pyramid: "}
    lappend row {skip}
    lappend row {label "Step(s)"}
    dialog_create_stdrow $input 2 $row

    entry $input.stepsent -width 5 -textvariable SegmentVar(steps)
    grid $input.stepsent -row 2 -column 2 -sticky w

    set SegmentVar(entry,fg) [$input.stepsent cget -fg]
    set SegmentVar(entry,bg) [$input.stepsent cget -bg]
    
    segment_update
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SegmentVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        segment_run    
    }


    destroy $top
}
proc segment_update {} {
    global SegmentVar

    set input [dialog_input .segmentdlg]

    if {$SegmentVar(reduction)} {
	$input.stepsent configure -state normal -fg $SegmentVar(entry,fg)
	set SegmentVar(steps) 1
    } else {
	$input.stepsent configure -state disabled -fg $SegmentVar(entry,bg)
	set SegmentVar(steps) 0
    }
}
#
# segment_run --
#
#       Define a new region based on the parameters from the
#       segment dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc segment_run {} {
    global SegmentVar
    
    set out_sadie_addr [Sadie_Classify_Segment SegmentVar]

    create_display_image $SegmentVar(outname) $out_sadie_addr
}
#
# segment_init --
#
#       Initialize the parameters for the segment dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc segment_init {} {
    global SegmentVar
    
    set SegmentVar(inimg,array) "none"
    set SegmentVar(inimg,name) "none"
    set SegmentVar(inimg,addr) "none"
    set SegmentVar(steps) 0
    set SegmentVar(reduction) 0
    set SegmentVar(sigma) 5.0
    set SegmentVar(thresh) 10.0
    set SegmentVar(outname) "Segment"
}




#
# sigmap_dialog --
#
#       Create a dialog box for performing a signature map on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc sigmap_dialog { } {
    global SigmapVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .sigmapdlg]
    wm geometry $top +110+110
    wm title $top "Signature Map Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Create a Signature Map"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Label Map: "}
    lappend row {imgchooser SigmapVar(lblmap,addr) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Original Image: "}
    lappend row {imgchooser SigmapVar(origimg,addr) 1}
    dialog_create_stdrow $input 1 $row

    
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SigmapVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        sigmap_run    
    }


    destroy $top
}
#
# sigmap_run --
#
#       Define a new region based on the parameters from the
#       sigmap dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc sigmap_run {} {
    global SigmapVar
    
    set out_sadie_addr [Sadie_Classify_SigMap SigmapVar]

    create_display_image $SigmapVar(outname) $out_sadie_addr
}
#
# sigmap_init --
#
#       Initialize the parameters for the sigmap dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc sigmap_init {} {
    global SigmapVar
    
    set SigmapVar(lblmap,addr) ""
    set SigmapVar(origimg,addr) ""
    set SigmapVar(outname) "Signature Map"
}
