#
# tclSadie_contrastmenu_init --
#
#       Initialize the parameters for the all of the contrast menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_contrastmenu_init {} {
    normalstr_init
    histeqstr_init
    linearstr_init
    logstr_init
    pwlstr_init
    rootstr_init
    squarestr_init
    tlookupstr_init
    requantstr_init
    saturatestr_init
    threshstr_init
    adaptstr_init
    referencestr_init
}



#
# normalstr_dialog --
#
#       Create a dialog box for performing a normalization stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc normalstr_dialog { } {
    global NormalstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set NormalstrVar(inimg,array) [get_current_image]
    if {$NormalstrVar(inimg,array) != "none"} {
	    upvar #0 $NormalstrVar(inimg,array) imgarray
	    set NormalstrVar(inimg,name) $imgarray(title)
	    set NormalstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .normalstrdlg]
    wm geometry $top +110+110
    wm title $top "Normalize Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Normalization Stretch on: "
    label $title.imglbl -fg blue -text $NormalstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.meanlbl -text "Graylevel: "
    entry $input.meanent -width 5 -textvariable NormalstrVar(mean)
    label $input.meanunits -text "Mean"

    entry $input.devent -width 5 -textvariable NormalstrVar(sigma)
    label $input.devunits -text "Standard Deviation"

    label $input.incrlbl -text "Subsample Increment: "
    entry $input.incrent -width 5 -textvariable NormalstrVar(incr)
    label $input.incrunits -text "Pixel(s) and Line(s)"

    grid $input.meanlbl -row 0 -column 0 -sticky w
    grid $input.meanent -row 0 -column 1 -sticky w
    grid $input.meanunits -row 0 -column 2 -sticky w    

    grid $input.devent -row 1 -column 1 -sticky w
    grid $input.devunits -row 1 -column 2 -sticky w    

    grid $input.incrlbl -row 2 -column 0 -sticky w
    grid $input.incrent -row 2 -column 1 -sticky w
    grid $input.incrunits -row 2 -column 2 -sticky w    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable NormalstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        normalstr_run    
    }


    destroy $top
}
#
# normalstr_run --
#
#       Define a new region based on the parameters from the
#       normalstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc normalstr_run {} {
    global NormalstrVar
    
    set out_sadie_addr [Sadie_Contrast_NormStretch NormalstrVar]

    create_display_image $NormalstrVar(outname) $out_sadie_addr
}
#
# normalstr_init --
#
#       Initialize the parameters for the normalstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc normalstr_init {} {
    global NormalstrVar
    
    set NormalstrVar(inimg,array) "none"
    set NormalstrVar(inimg,name) "none"
    set NormalstrVar(inimg,addr) "none"
    set NormalstrVar(mean) 128.0
    set NormalstrVar(sigma) 32.0
    set NormalstrVar(incr) 1
    set NormalstrVar(outname) "NormStr"
}



#
# histeqstr_dialog --
#
#       Create a dialog box for performing a histogram equalization stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc histeqstr_dialog { } {
    global HisteqstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set HisteqstrVar(inimg,array) [get_current_image]
    if {$HisteqstrVar(inimg,array) != "none"} {
	    upvar #0 $HisteqstrVar(inimg,array) imgarray
	    set HisteqstrVar(inimg,name) $imgarray(title)
	    set HisteqstrVar(inimg,addr) $imgarray(sadie_addr)
	    set HisteqstrVar(res) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .histeqstrdlg]
    wm geometry $top +110+110
    wm title $top "Histogram Equalization Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Histogram Equalization Stretch on: "
    label $title.imglbl -fg blue -text $HisteqstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Histogram Resolution: "}
    lappend row {entry HisteqstrVar(res)}
    lappend row {label "Bin(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Subsample Increment: "}
    lappend row {entry HisteqstrVar(incr)}
    lappend row {label "Pixel(s) and Line(s)"}
    dialog_create_stdrow $input 1 $row
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable HisteqstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        histeqstr_run    
    }


    destroy $top
}
#
# histeqstr_run --
#
#       Define a new region based on the parameters from the
#       histeqstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc histeqstr_run {} {
    global HisteqstrVar
    
    set out_sadie_addr [Sadie_Contrast_HisteqStretch HisteqstrVar]

    create_display_image $HisteqstrVar(outname) $out_sadie_addr
}
#
# histeqstr_init --
#
#       Initialize the parameters for the histeqstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc histeqstr_init {} {
    global HisteqstrVar
    
    set HisteqstrVar(inimg,array) "none"
    set HisteqstrVar(inimg,name) "none"
    set HisteqstrVar(inimg,addr) "none"
    set HisteqstrVar(res) 1
    set HisteqstrVar(incr) 1
    set HisteqstrVar(outname) "HisteqStr"
}



#
# linearstr_dialog --
#
#       Create a dialog box for performing a linear stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc linearstr_dialog { } {
    global LinearstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set LinearstrVar(inimg,array) [get_current_image]
    if {$LinearstrVar(inimg,array) != "none"} {
	    upvar #0 $LinearstrVar(inimg,array) imgarray
	    set LinearstrVar(inimg,name) $imgarray(title)
	    set LinearstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .linearstrdlg]
    wm geometry $top +110+110
    wm title $top "Linear Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Linear Stretch on: "
    label $title.imglbl -fg blue -text $LinearstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {radiobutton "Min / Max    " LinearstrVar(type) 0 linearstr_update}
    lappend row {entry LinearstrVar(minorbias)}
    lappend row [subst {label \"$LinearstrVar(minbiaslbl)\" LinearstrVar(minbiaslbl)}]
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {radiobutton "Bias / Gain    " LinearstrVar(type) 1 linearstr_update}
    lappend row {entry LinearstrVar(maxorgain)}
    lappend row [subst {label \"$LinearstrVar(maxgainlbl)\" LinearstrVar(maxgainlbl)}]
    dialog_create_stdrow $input 1 $row

    grid columnconfigure $input 2 -minsize 150

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable LinearstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        linearstr_run    
    }


    destroy $top
}
proc linearstr_update {} {
    global LinearstrVar

    if {$LinearstrVar(type)} {
	set LinearstrVar(minbiaslbl) "Bias"
	set LinearstrVar(maxgainlbl) "Gain"
	set LinearstrVar(minorbias) 0.0
	set LinearstrVar(maxorgain) 1.0
    } else {
	set LinearstrVar(minbiaslbl) "Minimum Graylevel"
	set LinearstrVar(maxgainlbl) "Maximum Graylevel"
	set LinearstrVar(minorbias) 0.0
	set LinearstrVar(maxorgain) 255.0
    }
}
#
# linearstr_run --
#
#       Define a new region based on the parameters from the
#       linearstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc linearstr_run {} {
    global LinearstrVar
    
    set out_sadie_addr [Sadie_Contrast_LinearStretch LinearstrVar]

    create_display_image $LinearstrVar(outname) $out_sadie_addr
}
#
# linearstr_init --
#
#       Initialize the parameters for the linearstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc linearstr_init {} {
    global LinearstrVar
    
    set LinearstrVar(inimg,array) "none"
    set LinearstrVar(inimg,name) "none"
    set LinearstrVar(inimg,addr) "none"
    set LinearstrVar(type) 0
    set LinearstrVar(minorbias) 0.0
    set LinearstrVar(maxorgain) 255.0
    set LinearstrVar(minbiaslbl) "Minimum Graylevel"
    set LinearstrVar(maxgainlbl) "Maximum Graylevel"
    set LinearstrVar(outname) "Linearstr"
}





#
# logstr_dialog --
#
#       Create a dialog box for performing a logarithm stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc logstr_dialog { } {
    global LogstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set LogstrVar(inimg,array) [get_current_image]
    if {$LogstrVar(inimg,array) != "none"} {
	    upvar #0 $LogstrVar(inimg,array) imgarray
	    set LogstrVar(inimg,name) $imgarray(title)
	    set LogstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .logstrdlg]
    wm geometry $top +110+110
    wm title $top "Logarithmic Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Logarithmic Stretch on: "
    label $title.imglbl -fg blue -text $LogstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable LogstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        logstr_run    
    }


    destroy $top
}
#
# logstr_run --
#
#       Define a new region based on the parameters from the
#       logstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc logstr_run {} {
    global LogstrVar
    
    set out_sadie_addr [Sadie_Contrast_LogStretch LogstrVar]

    create_display_image $LogstrVar(outname) $out_sadie_addr
}
#
# logstr_init --
#
#       Initialize the parameters for the logstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc logstr_init {} {
    global LogstrVar
    
    set LogstrVar(inimg,array) "none"
    set LogstrVar(inimg,name) "none"
    set LogstrVar(inimg,addr) "none"
    set LogstrVar(outname) "LogStr"
}











#
# pwlstr_dialog --
#
#       Create a dialog box for performing a Piecewise Linear stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc pwlstr_dialog { } {
    global PwlstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set PwlstrVar(inimg,array) [get_current_image]
    if {$PwlstrVar(inimg,array) != "none"} {
	    upvar #0 $PwlstrVar(inimg,array) imgarray
	    set PwlstrVar(inimg,name) $imgarray(title)
	    set PwlstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .pwlstrdlg]
    wm geometry $top +110+110
    wm title $top "Piecewise Linear Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Piecewise Linear Stretch on: "
    label $title.imglbl -fg blue -text $PwlstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    label $input.graylbl -text "Graylevel Breakpoints:"

    label $input.inputlbl -text "Input: "
    entry $input.inputent1 -width 5 -textvariable PwlstrVar(in1)
    entry $input.inputent2 -width 5 -textvariable PwlstrVar(in2)
    entry $input.inputent3 -width 5 -textvariable PwlstrVar(in3)
    entry $input.inputent4 -width 5 -textvariable PwlstrVar(in4)
    
    label $input.outputlbl -text "Output: "
    entry $input.outputent1 -width 5 -textvariable PwlstrVar(out1)
    entry $input.outputent2 -width 5 -textvariable PwlstrVar(out2)
    entry $input.outputent3 -width 5 -textvariable PwlstrVar(out3)
    entry $input.outputent4 -width 5 -textvariable PwlstrVar(out4)
    
    grid $input.graylbl -row 0 -column 0 -columnspan 4 -sticky w
    grid $input.inputlbl -row 1 -column 0 -sticky w
    grid $input.inputent1 -row 1 -column 1 -sticky w
    grid $input.inputent2 -row 1 -column 2 -sticky w
    grid $input.inputent3 -row 1 -column 3 -sticky w
    grid $input.inputent4 -row 1 -column 4 -sticky w

    grid $input.outputlbl -row 2 -column 0 -sticky w
    grid $input.outputent1 -row 2 -column 1 -sticky w
    grid $input.outputent2 -row 2 -column 2 -sticky w
    grid $input.outputent3 -row 2 -column 3 -sticky w
    grid $input.outputent4 -row 2 -column 4 -sticky w


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable PwlstrVar(outname)


    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        pwlstr_run    
    }


    destroy $top
}
#
# pwlstr_run --
#
#       Define a new region based on the parameters from the
#       pwlstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc pwlstr_run {} {
    global PwlstrVar
    
    set out_sadie_addr [Sadie_Contrast_PWLStretch PwlstrVar]

    create_display_image $PwlstrVar(outname) $out_sadie_addr
}
#
# pwlstr_init --
#
#       Initialize the parameters for the pwlstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc pwlstr_init {} {
    global PwlstrVar
    
    set PwlstrVar(inimg,array) "none"
    set PwlstrVar(inimg,name) "none"
    set PwlstrVar(inimg,addr) "none"
    set PwlstrVar(in1) "0.0"
    set PwlstrVar(in2) "85.0"
    set PwlstrVar(in3) "170.0"
    set PwlstrVar(in4) "255.0"
    set PwlstrVar(out1) "0.0"
    set PwlstrVar(out2) "85.0"
    set PwlstrVar(out3) "170.0"
    set PwlstrVar(out4) "255.0"
    set PwlstrVar(outname) "PWLStr"
}



#
# rootstr_dialog --
#
#       Create a dialog box for performing a square root stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc rootstr_dialog { } {
    global RootstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set RootstrVar(inimg,array) [get_current_image]
    if {$RootstrVar(inimg,array) != "none"} {
	    upvar #0 $RootstrVar(inimg,array) imgarray
	    set RootstrVar(inimg,name) $imgarray(title)
	    set RootstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .rootstrdlg]
    wm geometry $top +110+110
    wm title $top "Square Root Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Square Root Stretch on: "
    label $title.imglbl -fg blue -text $RootstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RootstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        rootstr_run    
    }


    destroy $top
}
#
# rootstr_run --
#
#       Define a new region based on the parameters from the
#       rootstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc rootstr_run {} {
    global RootstrVar
    
    set out_sadie_addr [Sadie_Contrast_RootStretch RootstrVar]

    create_display_image $RootstrVar(outname) $out_sadie_addr
}
#
# rootstr_init --
#
#       Initialize the parameters for the rootstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc rootstr_init {} {
    global RootstrVar
    
    set RootstrVar(inimg,array) "none"
    set RootstrVar(inimg,name) "none"
    set RootstrVar(inimg,addr) "none"
    set RootstrVar(outname) "SqrRootStr"
}



#
# squarestr_dialog --
#
#       Create a dialog box for performing a square stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc squarestr_dialog { } {
    global SquarestrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set SquarestrVar(inimg,array) [get_current_image]
    if {$SquarestrVar(inimg,array) != "none"} {
	    upvar #0 $SquarestrVar(inimg,array) imgarray
	    set SquarestrVar(inimg,name) $imgarray(title)
	    set SquarestrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .squarestrdlg]
    wm geometry $top +110+110
    wm title $top "Square Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Square Stretch on: "
    label $title.imglbl -fg blue -text $SquarestrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SquarestrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        squarestr_run    
    }


    destroy $top
}
#
# squarestr_run --
#
#       Define a new region based on the parameters from the
#       squarestr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc squarestr_run {} {
    global SquarestrVar
    
    set out_sadie_addr [Sadie_Contrast_SqrStretch SquarestrVar]

    create_display_image $SquarestrVar(outname) $out_sadie_addr
}
#
# squarestr_init --
#
#       Initialize the parameters for the squarestr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc squarestr_init {} {
    global SquarestrVar
    
    set SquarestrVar(inimg,array) "none"
    set SquarestrVar(inimg,name) "none"
    set SquarestrVar(inimg,addr) "none"
    set SquarestrVar(outname) "SquareStr"
}






#
# tlookupstr_dialog --
#
#       Create a dialog box for performing a table lookup stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc tlookupstr_dialog { } {
    global TlookupstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set TlookupstrVar(inimg,array) [get_current_image]
    if {$TlookupstrVar(inimg,array) != "none"} {
	    upvar #0 $TlookupstrVar(inimg,array) imgarray
	    set TlookupstrVar(inimg,name) $imgarray(title)
	    set TlookupstrVar(inimg,addr) $imgarray(sadie_addr)
	    set TlookupstrVar(nlev) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .tlookupstrdlg]
    wm geometry $top +110+110
    wm title $top "Table Lookup Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Table Lookup Stretch on: "
    label $title.imglbl -fg blue -text $TlookupstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    label $input.tbllbl -text "Lookup Table:   "

    scrollform_create $input.scrlform
    set form [scrollform_interior $input.scrlform]
    label $form.indexlbl -text "  Index    "
    label $form.valuelbl -text " Value     "
    grid $form.indexlbl $form.valuelbl -sticky nw

    for {set i 0} {$i < $TlookupstrVar(nlev)} {incr i} {
	label $form.index$i -text [format "%6d" $i]
	entry $form.ent$i -textvariable TlookupstrVar(index,$i) -width 6
	set TlookupstrVar(index,$i) [format "%.1f" $i]
	grid $form.index$i $form.ent$i -sticky nws
    }

    grid $input.tbllbl $input.scrlform -sticky nws
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable TlookupstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        tlookupstr_run    
    }


    destroy $top
}
#
# tlookupstr_run --
#
#       Define a new region based on the parameters from the
#       tlookupstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc tlookupstr_run {} {
    global TlookupstrVar
    
    set out_sadie_addr [Sadie_Contrast_TblStretch TlookupstrVar]

    create_display_image $TlookupstrVar(outname) $out_sadie_addr
}
#
# tlookupstr_init --
#
#       Initialize the parameters for the tlookupstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc tlookupstr_init {} {
    global TlookupstrVar
    
    set TlookupstrVar(inimg,array) "none"
    set TlookupstrVar(inimg,name) "none"
    set TlookupstrVar(inimg,addr) "none"
    set TlookupstrVar(outname) "TableStr"
}



#
# requantstr_dialog --
#
#       Create a dialog box for performing a requantize stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc requantstr_dialog { } {
    global RequantstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set RequantstrVar(inimg,array) [get_current_image]
    if {$RequantstrVar(inimg,array) != "none"} {
	upvar #0 $RequantstrVar(inimg,array) imgarray
	set RequantstrVar(inimg,name) $imgarray(title)
	set RequantstrVar(inimg,addr) $imgarray(sadie_addr)
	set RequantstrVar(gmin) [format "%.1f" [Sadie_General_Gmin $imgarray(sadie_addr)]]
	set RequantstrVar(gmax) [format "%.1f" [Sadie_General_Gmax $imgarray(sadie_addr)]]
	set RequantstrVar(steps) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .requantstrdlg]
    wm geometry $top +110+110
    wm title $top "Requantize Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Requantize Stretch on: "
    label $title.imglbl -fg blue -text $RequantstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Graylevel: "}
    lappend row {entry RequantstrVar(gmin)}
    lappend row {label "Minimum"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {skip}
    lappend row {entry RequantstrVar(gmax)}
    lappend row {label "Maximum"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {skip}
    lappend row {entry RequantstrVar(steps)}
    lappend row {label "Quantization Steps"}
    dialog_create_stdrow $input 2 $row


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RequantstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        requantstr_run    
    }


    destroy $top
}
#
# requantstr_run --
#
#       Define a new region based on the parameters from the
#       requantstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc requantstr_run {} {
    global RequantstrVar
    
    set out_sadie_addr [Sadie_Contrast_QntStretch RequantstrVar]

    create_display_image $RequantstrVar(outname) $out_sadie_addr
}
#
# requantstr_init --
#
#       Initialize the parameters for the requantstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc requantstr_init {} {
    global RequantstrVar
    
    set RequantstrVar(inimg,array) "none"
    set RequantstrVar(inimg,name) "none"
    set RequantstrVar(inimg,addr) "none"
    set RequantstrVar(outname) "RequantStr"
}



#
# saturatestr_dialog --
#
#       Create a dialog box for performing a saturation stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc saturatestr_dialog { } {
    global SaturatestrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set SaturatestrVar(inimg,array) [get_current_image]
    if {$SaturatestrVar(inimg,array) != "none"} {
	upvar #0 $SaturatestrVar(inimg,array) imgarray
	set SaturatestrVar(inimg,name) $imgarray(title)
	set SaturatestrVar(inimg,addr) $imgarray(sadie_addr)
	set SaturatestrVar(gmin) [format "%.1f" [Sadie_General_Gmin $imgarray(sadie_addr)]]
	set SaturatestrVar(gmax) [format "%.1f" [Sadie_General_Gmax $imgarray(sadie_addr)]]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .saturatestrdlg]
    wm geometry $top +110+110
    wm title $top "Saturation Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Saturation Stretch on: "
    label $title.imglbl -fg blue -text $SaturatestrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Graylevel: "}
    lappend row {entry SaturatestrVar(gmin)}
    lappend row {label "Minimum"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {skip}
    lappend row {entry SaturatestrVar(gmax)}
    lappend row {label "Maximum"}
    dialog_create_stdrow $input 1 $row


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SaturatestrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        saturatestr_run    
    }


    destroy $top
}
#
# saturatestr_run --
#
#       Define a new region based on the parameters from the
#       saturatestr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc saturatestr_run {} {
    global SaturatestrVar
    
    set out_sadie_addr [Sadie_Contrast_SatStretch SaturatestrVar]

    create_display_image $SaturatestrVar(outname) $out_sadie_addr
}
#
# saturatestr_init --
#
#       Initialize the parameters for the saturatestr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc saturatestr_init {} {
    global SaturatestrVar
    
    set SaturatestrVar(inimg,array) "none"
    set SaturatestrVar(inimg,name) "none"
    set SaturatestrVar(inimg,addr) "none"
    set SaturatestrVar(outname) "SaturateStr"
}



#
# threshstr_dialog --
#
#       Create a dialog box for performing a threshold stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc threshstr_dialog { } {
    global ThreshstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set ThreshstrVar(inimg,array) [get_current_image]
    if {$ThreshstrVar(inimg,array) != "none"} {
	upvar #0 $ThreshstrVar(inimg,array) imgarray
	set ThreshstrVar(inimg,name) $imgarray(title)
	set ThreshstrVar(inimg,addr) $imgarray(sadie_addr)
	set ThreshstrVar(thresh) [format "%.1f" [expr double([Sadie_General_Gmax $imgarray(sadie_addr)] + [Sadie_General_Gmin $imgarray(sadie_addr)]) / 2.0]]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .threshstrdlg]
    wm geometry $top +110+110
    wm title $top "Threshold Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Threshold Stretch on: "
    label $title.imglbl -fg blue -text $ThreshstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Graylevel Threshold: "}
    lappend row {entry ThreshstrVar(thresh)}
    dialog_create_stdrow $input 0 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ThreshstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        threshstr_run    
    }


    destroy $top
}
#
# threshstr_run --
#
#       Define a new region based on the parameters from the
#       threshstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc threshstr_run {} {
    global ThreshstrVar
    
    set out_sadie_addr [Sadie_Contrast_ThreshStretch ThreshstrVar]

    create_display_image $ThreshstrVar(outname) $out_sadie_addr
}
#
# threshstr_init --
#
#       Initialize the parameters for the threshstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc threshstr_init {} {
    global ThreshstrVar
    
    set ThreshstrVar(inimg,array) "none"
    set ThreshstrVar(inimg,name) "none"
    set ThreshstrVar(inimg,addr) "none"
    set ThreshstrVar(outname) "ThreshStr"
}



#
# adaptstr_dialog --
#
#       Create a dialog box for performing an adapt stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc adaptstr_dialog { } {
    global AdaptstrVar
    global confirmStatus

    #
    # Determine the current image
    #
    set AdaptstrVar(inimg,array) [get_current_image]
    if {$AdaptstrVar(inimg,array) != "none"} {
	upvar #0 $AdaptstrVar(inimg,array) imgarray
	set AdaptstrVar(inimg,name) $imgarray(title)
	set AdaptstrVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .adaptstrdlg]
    wm geometry $top +110+110
    wm title $top "Adapt Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Adapt Stretch on: "
    label $title.imglbl -fg blue -text $AdaptstrVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Block Size: "}
    lappend row {entry AdaptstrVar(blocksize)}
    lappend row {label "Pixel(s) and Line(s)"}
    dialog_create_stdrow $input 0 $row


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable AdaptstrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        adaptstr_run    
    }


    destroy $top
}
#
# adaptstr_run --
#
#       Define a new region based on the parameters from the
#       adaptstr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc adaptstr_run {} {
    global AdaptstrVar
    
    set out_sadie_addr [Sadie_Contrast_AdaptStretch AdaptstrVar]

    create_display_image $AdaptstrVar(outname) $out_sadie_addr
}
#
# adaptstr_init --
#
#       Initialize the parameters for the adaptstr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc adaptstr_init {} {
    global AdaptstrVar
    
    set AdaptstrVar(inimg,array) "none"
    set AdaptstrVar(inimg,name) "none"
    set AdaptstrVar(inimg,addr) "none"
    set AdaptstrVar(blocksize) 16
    set AdaptstrVar(outname) "AdaptStr"
}




#
# referencestr_dialog --
#
#       Create a dialog box for performing a reference stretch on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc referencestr_dialog { } {
    global ReferencestrVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .referencestrdlg]
    wm geometry $top +110+110
    wm title $top "Reference Stretch Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Reference Stretch"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Transformation Image: "}
    lappend row {imgchooser ReferencestrVar(inimg,addr1) 0 2}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Reference Image: "}
    lappend row {imgchooser ReferencestrVar(inimg,addr2) 1 2}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Lookup Table: "}
    lappend row {entry ReferencestrVar(nlevels)}
    lappend row {label "Entries"}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label "Transformation: "}
    lappend row {radiobutton "Least Squares"  ReferencestrVar(option) 0 NOP 3}
    dialog_create_stdrow $input 3 $row

    set row {}
    lappend row {skip}
    lappend row {radiobutton "Cumulative Distribution"  ReferencestrVar(option) 1 NOP 3}
    dialog_create_stdrow $input 4 $row

    grid columnconfigure $input 3 -weight 1
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ReferencestrVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        referencestr_run    
    }


    destroy $top
}
#
# referencestr_run --
#
#       Define a new region based on the parameters from the
#       referencestr dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc referencestr_run {} {
    global ReferencestrVar
    
    set out_sadie_addr [Sadie_Contrast_RefStretch ReferencestrVar]

    create_display_image $ReferencestrVar(outname) $out_sadie_addr
}
#
# referencestr_init --
#
#       Initialize the parameters for the referencestr dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc referencestr_init {} {
    global ReferencestrVar
    
    set ReferencestrVar(option) 0
    set ReferencestrVar(nlevels) 256
    set ReferencestrVar(outname) "ReferenceStr"
}

