proc tclSadie_fileIO_init {} {
    # Load Img package. It supports:
    # XBM,XPM,PNG,PS,TIFF,JPEG,PNM
    package require Img

    sadiesave_init
    jpegsave_init
    tiffsave_init
    import_image_init
}


proc open_image_from_file {} {
    global SadieVar
    global ImportVar

    set types {
	{{IPT Format} {*.ipt}}
	{{IPT Format} {*.sad}}
	{{BMP}  {*.bmp}}
	{{GIF}  {*.gif}}
	{{JPEG} {*.jpg}}
	{{PNG}  {*.png}}
	{{PNM}  {*.pgm}}
	{{PNM}  {*.ppm}}
	{{Postscript} {*.ps}}
	{{TIFF} {*.tif}}
	{{XBM}  {*.xbm}}
	{{XPM}  {*.xpm}}
    }
    
    # The following lines will duplicate the file types for
    # upper case extensions.
    set numtypes [llength $types]
    for {set i 0} {$i < $numtypes} {incr i} {
	set lcasetype [lindex $types $i]
	lappend types [list [lindex $lcasetype 0] [string toupper [lindex $lcasetype 1]]]
    }
    
    # The following method is no longer used.
    # set result [tclSadie_FileDialog open -title "Open Image" -filetypes $types]

    #Instead use this
    set result [tk_getOpenFile -title "Open Image" -filetypes $types]
    
    if {$result == ""} {
	return 0;
    }

    set file $result
    set format [file extension $file]
    set out_title [file tail $file]
    set filesize [file size $file]
    set format [string toupper [string trimleft $format {.}]]

    switch -exact $format {
	IPT  {set format "sadie"}
	SAD  {set format "sadie"}
	TIF  {set format "TIFF"}
	JPG  {set format "JPEG"}
	PS   {set format "POSTSCRIPT"}
    }
	
    if {$format == "sadie"} {
	
	set sadie_addr [Sadie_FileIO_Open $file $filesize $out_title]
	create_display_image $out_title $sadie_addr

    } elseif {$format == "BMP" || $format == "GIF" \
	    || $format == "JPEG" || $format == "PNG" \
	    || $format == "POSTSCRIPT" || $format == "XBM" \
	    || $format == "XPM" || $format == "TIFF"} {

	# This formats are supported by the Img package

	# Temporarily load the image into a Tk photo image
	image create photo tempimg -file $file -format $format

	# Convert the Tk photo to SADIE format
	set sadie_addr [tempimg write $out_title -format sadie]
	
	image delete tempimg
	create_display_image $out_title $sadie_addr
	
    } elseif {$format == "PGM" || $format == "PPM"} {

	set sadie_addr [Sadie_FileIO_OpenPNM $file $out_title]
	create_display_image $out_title $sadie_addr
	
    } else {
	error "Image format: \"$format\" is not yet supported"
	return 0
    }

}


proc import_image_from_file {} {
    global SadieVar

    set types {
	{{Import} {*}}
    }

    # The following method is no longer used.
    # set result [tclSadie_FileDialog open -title "Import Image" -filetypes $types]

    #Instead use this
    set result [tk_getOpenFile -title "Import Image" -filetypes $types]
    
    if {$result == ""} {
	return 0;
    }

    set file $result
    set filesize [file size $file]
    
    import_image_dialog $file $filesize

}


#
# import_image_dialog --
#
#       Create a dialog box for importing an image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc import_image_dialog {file filesize} {
    global ImportVar
    global confirmStatus

    set ImportVar(file) $file

    set ImportVar(filesize) $filesize
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .import_imagedlg]
    wm geometry $top +110+110
    wm title $top "File Import Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Import Image: "
    label $title.imglbl -fg blue -text $ImportVar(file)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    entry $input.headerent -width 5 -textvariable ImportVar(header)
    label $input.headerlbl -text "Bytes/Header"

    entry $input.bandsent -width 5 -textvariable ImportVar(bands)
    label $input.bandslbl -text "Bands/Image"

    entry $input.linesent -width 5 -textvariable ImportVar(lines)
    label $input.lineslbl -text "Lines/Band"

    entry $input.pixelsent -width 5 -textvariable ImportVar(pixels)
    label $input.pixelslbl -text "Pixels/Line"

    entry $input.bitsent -width 5 -textvariable ImportVar(bits)
    label $input.bitslbl -text "Bits/Pixel"

    set option $input.option
    frame $option
    
    radiobutton $option.bil -text "BIL" \
	    -variable ImportVar(option) \
	    -value 0 \
	    -anchor w
    radiobutton $option.bsq -text "BSQ" \
	    -variable ImportVar(option) \
	    -value 1 \
	    -anchor w
    radiobutton $option.bip -text "BIP" \
	    -variable ImportVar(option) \
	    -value 2 \
	    -anchor w
    grid $option.bil -row 0 -column 0 -sticky ews
    grid $option.bsq -row 1 -column 0 -sticky new
    grid $option.bip -row 2 -column 0 -sticky new

    
    set winsub $input.winsub
    frame $winsub -bd 2 -relief ridge

    checkbutton $winsub.check -text "Window/Subsample" -onvalue 1 -offvalue 0 -variable ImportVar(winsub) \
	    -command "import_image_update $winsub"

    label $winsub.fromlbl -text "From: "
    entry $winsub.from_bandent -width 5 -textvariable ImportVar(from,band)
    label $winsub.from_bandlbl -text "Band "
    entry $winsub.from_lineent -width 5 -textvariable ImportVar(from,line)
    label $winsub.from_linelbl -text "Line "
    entry $winsub.from_pixelent -width 5 -textvariable ImportVar(from,pixel)
    label $winsub.from_pixellbl -text "Pixel "

    label $winsub.tolbl -text "To: "
    entry $winsub.to_bandent -width 5 -textvariable ImportVar(to,band)
    label $winsub.to_bandlbl -text "Band "
    entry $winsub.to_lineent -width 5 -textvariable ImportVar(to,line)
    label $winsub.to_linelbl -text "Line "
    entry $winsub.to_pixelent -width 5 -textvariable ImportVar(to,pixel)
    label $winsub.to_pixellbl -text "Pixel "
    
    label $winsub.incrlbl -text "Increment: "
    entry $winsub.incr_bandent -width 5 -textvariable ImportVar(incr,band)
    label $winsub.incr_bandlbl -text "Band(s) "
    entry $winsub.incr_lineent -width 5 -textvariable ImportVar(incr,line)
    label $winsub.incr_linelbl -text "Line(s) "
    entry $winsub.incr_pixelent -width 5 -textvariable ImportVar(incr,pixel)
    label $winsub.incr_pixellbl -text "Pixel(s) "

    grid $winsub.check -row 0 -column 0 -columnspan 5 -sticky nw
    grid rowconfigure $winsub 0 -minsize 25
    set i 0
    foreach type [list from to incr] {
	incr i
	
	grid $winsub.${type}lbl -row $i -column 0 -sticky w
	grid $winsub.${type}_bandent -row $i -column 1 -sticky w
	grid $winsub.${type}_bandlbl -row $i -column 2 -sticky w
	grid $winsub.${type}_lineent -row $i -column 3 -sticky w
	grid $winsub.${type}_linelbl -row $i -column 4 -sticky w
	grid $winsub.${type}_pixelent -row $i -column 5 -sticky w
	grid $winsub.${type}_pixellbl -row $i -column 6 -sticky w
    }
    
    grid $input.headerent -row 1 -column 1 -sticky w -pady 5
    grid $input.headerlbl -row 1 -column 2 -sticky w -pady 5
    grid $input.bandsent -row 2 -column 1 -sticky w -pady 5
    grid $input.bandslbl -row 2 -column 2 -sticky w -pady 5
    grid $input.linesent -row 3 -column 1 -sticky w -pady 5
    grid $input.lineslbl -row 3 -column 2 -sticky w -pady 5
    grid $input.pixelsent -row 4 -column 1 -sticky w -pady 5
    grid $input.pixelslbl -row 4 -column 2 -sticky w -pady 5
    grid $input.bitsent -row 5 -column 1 -sticky w -pady 5
    grid $input.bitslbl -row 5 -column 2 -sticky w -pady 5

    grid $input.option -row 1 -column 3 -rowspan 5 -pady 15 -padx 15 -sticky news

    grid $input.winsub -row 7 -column 0 -columnspan 5 -sticky sw
    grid rowconfigure $input 0 -minsize 10
    grid rowconfigure $input 6 -minsize 10
    grid columnconfigure $input 0 -minsize 25
    grid columnconfigure $input 4 -weight 1
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}

    import_image_update $winsub
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        import_image_run    
    }


    destroy $top
}


proc import_image_update {winsub} {
    global ImportVar
    
    if {$ImportVar(winsub) == 0} {
	set state disabled
	set fgcolor [$winsub.from_bandent cget -bg]
    } else {
	set state normal
	set fgcolor black
    }
    
    foreach type [list from to incr] {
	$winsub.${type}_bandent configure -state $state -fg $fgcolor
	$winsub.${type}_lineent configure -state $state -fg $fgcolor
	$winsub.${type}_pixelent configure -state $state -fg $fgcolor
    }
}


proc import_image_verify {} {
    global ImportVar

    if { $ImportVar(header) < 0 } {
	error "Expected positive header size but got: $ImportVar(header)"
    }
    if { $ImportVar(bands) < 0 } {
	error "Expected positive number of bands but got: $ImportVar(bands)"
    }
    if { $ImportVar(lines) < 0 } {
	error "Expected positive number of lines but got: $ImportVar(lines)"
    }
    if { $ImportVar(pixels) < 0 } {
	error "Expected positive number of pixels but got: $ImportVar(pixels)"
    }
    if { $ImportVar(bits) < 0 } {
	error "Expected positive number of bits/pixel but got: $ImportVar(bits)"
    }
    if { $ImportVar(bits) > 32 } {
	error "Expected bits/pixel < 32 but got: $ImportVar(bits)"
    }
}


#
# import_image_run --
#
#       Define a new region based on the parameters from the
#       import_image dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc import_image_run {} {
    global ImportVar
    
    import_image_verify

    set out_title [file tail $ImportVar(file)]
    
    set out_sadie_addr [Sadie_FileIO_Import $ImportVar(file) $ImportVar(header) $ImportVar(bands) \
	    $ImportVar(lines) $ImportVar(pixels) $ImportVar(bits) $ImportVar(option) $ImportVar(winsub) \
            $ImportVar(from,band) $ImportVar(to,band) $ImportVar(incr,band) \
	    $ImportVar(from,line) $ImportVar(to,line) $ImportVar(incr,line) \
	    $ImportVar(from,pixel) $ImportVar(to,pixel) $ImportVar(incr,pixel) \
	    $ImportVar(filesize) $out_title]

    create_display_image $out_title $out_sadie_addr
}


#
# import_image_init --
#
#       Initialize the parameters for the import_image dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc import_image_init {} {
    global ImportVar
    
    set ImportVar(file) ""
    set ImportVar(header) 512
    set ImportVar(bands) 1
    set ImportVar(lines) 200
    set ImportVar(pixels) 200
    set ImportVar(bits) 8
    set ImportVar(option) 1
    set ImportVar(winsub) 0

    set ImportVar(from,band) 1
    set ImportVar(from,line) 1
    set ImportVar(from,pixel) 1
    set ImportVar(to,band) 1
    set ImportVar(to,line) 200
    set ImportVar(to,pixel) 200
    set ImportVar(incr,band) 1
    set ImportVar(incr,line) 1
    set ImportVar(incr,pixel) 1
}


proc save_image_to_file {} {
    global SadieVar
    global SadiesaveVar
    global JPEGsaveVar
    global TIFFsaveVar
    
    set arrayName [get_current_image]
    if {$arrayName != "none"} {
	    upvar #0 $arrayName imgarray
    } else {
    	return 0
    }

    set types {
	{{IPT Format} {*.ipt}}
	{{IPT Format} {*.sad}}
	{{BMP}  {*.bmp}}
	{{EPSF} {*.eps}}
	{{GIF}  {*.gif}}
	{{JPEG} {*.jpg}}
	{{PNG}  {*.png}}
	{{PNM}  {*.pgm}}
	{{PNM}  {*.ppm}}
	{{Postscript} {*.ps}}
	{{Text} {*.txt}}
	{{TIFF} {*.tif}}
	{{XBM}  {*.xbm}}
	{{XPM}  {*.xpm}}
    }
    
    # The following lines will duplicate the file types for
    # upper case extensions
    set numtypes [llength $types]
    for {set i 0} {$i < $numtypes} {incr i} {
	set lcasetype [lindex $types $i]
	lappend types [list [lindex $lcasetype 0] [string toupper [lindex $lcasetype 1]]]
    }

    # The following method is no longer used.
    # set result [tclSadie_FileDialog save -title "Save Image" -filetypes $types]

    #Instead use this
    set result [tk_getSaveFile -title "Save Image" -filetypes $types]

    
    if {$result == ""} {
	return 0;
    }

    set file $result
    set format [file extension $file]
    set format [string toupper [string trimleft $format {.}]]

    switch -exact $format {
	IPT  {set format "sadie"}
	SAD  {set format "sadie"}
	JPG  {set format "JPEG"}
	PGM  {set format "PNM"}
	PPM  {set format "PNM"}
	TIF  {set format "TIFF"}
	PS   {set format "POSTSCRIPT"}
    }
    
    if {$format == "sadie"} {
	set SadiesaveVar(inimg,name) $file
	set SadiesaveVar(inimg,addr) $imgarray(sadie_addr)
	
	sadiesave_dialog
    } elseif {$format == "EPS"} {
	Sadie_FileIO_SaveEPS $imgarray(sadie_addr) $file 8
    } elseif {$format == "PNM"} {
	Sadie_FileIO_SavePNM $imgarray(sadie_addr) $file
    } elseif {$format == "BMP" || $format == "GIF" \
	    || $format == "XBM" || $format == "XPM" \
	    || $format == "PNG" || $format == "POSTSCRIPT"} {

	# Temporarily load the Sadie image into a Tk photo image.
	image create photo tempimg -data $imgarray(sadie_addr) -format sadie

	# The Img package will do the rest.
	tempimg write $file -format $format
    } elseif {$format == "JPEG"} {
	set JPEGsaveVar(inimg,name) $file
	set JPEGsaveVar(inimg,addr) $imgarray(sadie_addr)
	
	jpegsave_dialog
    } elseif {$format == "TIFF"} {
	set TIFFsaveVar(inimg,name) $file
	set TIFFsaveVar(inimg,addr) $imgarray(sadie_addr)
	
	tiffsave_dialog
    } elseif {$format == "TXT"} {
	Sadie_FileIO_SaveTEXT $imgarray(sadie_addr) $file
    } else {
	error "Image format: \"$format\" is not yet supported"
	return 0
    }

}


#
# sadiesave_dialog --
#
#       Create a dialog box to query bits/pixel for a SADIE save
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc sadiesave_dialog { } {
    global SadiesaveVar
    global confirmStatus


    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .sadiesavedlg]
    wm geometry $top +110+110
    wm title $top "SADIE File Save Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Save: "
    label $title.imglbl -fg blue -text $SadiesaveVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Pack to: "}
    lappend row {entry SadiesaveVar(bits)}
    lappend row {label "Bits / Pixel"}
    dialog_create_stdrow $input 0 $row
    # puts "SadiesaveVar(bits) is $SadiesaveVar(bits)\n"
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
# puts "SadiesaveVar(bits) is $SadiesaveVar(bits)\n"
        sadiesave_run    
    }


    destroy $top
}


proc sadiesave_run {} {
    global SadiesaveVar
    
    Sadie_FileIO_Save $SadiesaveVar(inimg,addr) $SadiesaveVar(inimg,name) $SadiesaveVar(bits)
}


#
# sadiesave_init --
#
#       Initialize the parameters for the SADIE file save dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc sadiesave_init {} {
    global SadiesaveVar
    
    set SadiesaveVar(bits) 8
}



#
# jpegsave_dialog --
#
#       Create a dialog box to query the following:
#           - Quality
#           - Smoothing
#           - Grayscale
#           - Optimization
#           - Progressive
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc jpegsave_dialog { } {
    global JPEGsaveVar
    global confirmStatus


    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .jpegsavedlg]
    wm geometry $top +110+110
    wm title $top "JPEG File Save Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Save: "
    label $title.imglbl -fg blue -text $JPEGsaveVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Quality: "}
    lappend row {scale JPEGsaveVar(quality) horizontal 175 25 3}
    lappend row {label " "}
    lappend row {entry JPEGsaveVar(quality)}
    dialog_create_stdrow $input 0 $row
    
    set row {}
    lappend row {label "Smoothing: "}
    lappend row {scale JPEGsaveVar(smooth) horizontal 175 25 3}
    lappend row {label " "}
    lappend row {entry JPEGsaveVar(smooth)}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {checkbutton "Grayscale" JPEGsaveVar(grayscale) 1 0}
    lappend row {label " "}
    lappend row {checkbutton "Progressive" JPEGsaveVar(progressive) 1 0}
    lappend row {label " "}
    lappend row {checkbutton "Optimize" JPEGsaveVar(optimize) 1 0}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        jpegsave_run    
    }


    destroy $top
}


proc jpegsave_run {} {
    global JPEGsaveVar

    lappend format {jpeg}
    
    if {$JPEGsaveVar(grayscale) == 1} {
	lappend format {-grayscale}
    }
    if {$JPEGsaveVar(progressive) == 1} {
	lappend format {-progressive}
    }
    if {$JPEGsaveVar(optimize) == 1} {
	lappend format {-optimize}
    }
    
    
    image create photo tempimg -data $JPEGsaveVar(inimg,addr) -format sadie
    tempimg write $JPEGsaveVar(inimg,name) -format $format
}


#
# jpegsave_init --
#
#       Initialize the parameters for the JPEG file save dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc jpegsave_init {} {
    global JPEGsaveVar
    
    set JPEGsaveVar(quality) 75
    set JPEGsaveVar(smooth) 0
    set JPEGsaveVar(grayscale) 0
    set JPEGsaveVar(progressive) 0
    set JPEGsaveVar(optimize) 0
}



#
# tiffsave_dialog --
#
#       Create a dialog box to query the following:
#           - Compression
#           - byteorder
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc tiffsave_dialog { } {
    global TIFFsaveVar
    global confirmStatus


    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .tiffsavedlg]
    wm geometry $top +110+110
    wm title $top "TIFF File Save Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Save: "
    label $title.imglbl -fg blue -text $TIFFsaveVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Compression: "}
    lappend row {radiobutton "None     " TIFFsaveVar(compression) 0}
    lappend row {label " "}
    lappend row {label "Byte Order: "}
    lappend row {radiobutton "Default      " TIFFsaveVar(byteorder) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label ""}
    lappend row {radiobutton "JPEG     " TIFFsaveVar(compression) 1}
    lappend row {label " "}
    lappend row {label ""}
    lappend row {radiobutton "Little(Small) Endian" TIFFsaveVar(byteorder) 1}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label ""}
    lappend row {radiobutton "Pack Bits" TIFFsaveVar(compression) 2}
    lappend row {label " "}
    lappend row {label ""}
    lappend row {radiobutton "Big Endian (Network)" TIFFsaveVar(byteorder) 2}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label ""}
    lappend row {radiobutton "Deflate  " TIFFsaveVar(compression) 3}
    lappend row {label " "}
    lappend row {label ""}
    lappend row {label ""}
    dialog_create_stdrow $input 3 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        tiffsave_run    
    }


    destroy $top
}


proc tiffsave_run {} {
    global TIFFsaveVar

    lappend format {tiff}
    
    lappend format {-compression}
    if {$TIFFsaveVar(compression) == 0} {
	lappend format {none}
    } elseif {$TIFFsaveVar(compression) == 1} {
	lappend format {jpeg}
    } elseif {$TIFFsaveVar(compression) == 2} {
	lappend format {packbits}
    } elseif {$TIFFsaveVar(compression) == 3} {
	lappend format {deflate}
    }

    lappend format {-byteorder}
    if {$TIFFsaveVar(byteorder) == 0} {
	lappend format {}
    } elseif {$TIFFsaveVar(byteorder) == 1} {
	lappend format {littleendian}
    } elseif {$TIFFsaveVar(byteorder) == 2} {
	lappend format {bigendian}
    }
    
    image create photo tempimg -data $TIFFsaveVar(inimg,addr) -format sadie
    tempimg write $TIFFsaveVar(inimg,name) -format $format
}


#
# tiffsave_init --
#
#       Initialize the parameters for the TIFF file save dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc tiffsave_init {} {
    global TIFFsaveVar
    
    set TIFFsaveVar(compression) 0 
    set TIFFsaveVar(byteorder) 0
}












