#
# tclSadie_geometrymenu_init --
#
#       Initialize the parameters for the all of the geometry menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_geometrymenu_init {} {
    avgsubsamp_init
    winsubsamp_init
    linearscale_init
    rotate_init
    mirror_init
    controlpt_init
    polywarp_init
    horizmosaic_init
    vertmosaic_init
    genmosaic_init
    insert_init
}



#
# avgsubsamp_dialog --
#
#       Create a dialog box for performing an average and subsample  on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc avgsubsamp_dialog { } {
    global AvgsubsampVar
    global confirmStatus

    #
    # Determine the current image
    #
    set AvgsubsampVar(inimg,array) [get_current_image]
    if {$AvgsubsampVar(inimg,array) != "none"} {
	    upvar #0 $AvgsubsampVar(inimg,array) imgarray
	    set AvgsubsampVar(inimg,name) $imgarray(title)
	    set AvgsubsampVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .avgsubsampdlg]
    wm geometry $top +110+110
    wm title $top "Average and Subsample Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Average and Subsample on: "
    label $title.imglbl -fg blue -text $AvgsubsampVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Window Size: "}
    lappend row {entry AvgsubsampVar(lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry AvgsubsampVar(pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Increment: "}
    lappend row {entry AvgsubsampVar(incrlines)}
    lappend row {label "Line(s)   "}
    lappend row {entry AvgsubsampVar(incrpix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable AvgsubsampVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        avgsubsamp_run    
    }
}
#
# avgsubsamp_run --
#
#       Define a new region based on the parameters from the
#       avgsubsamp dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc avgsubsamp_run {} {
    global AvgsubsampVar
    set out_sadie_addr [Sadie_Geometry_AvgSub AvgsubsampVar]
    create_display_image $AvgsubsampVar(outname) $out_sadie_addr
}
#
# avgsubsamp_init --
#
#       Initialize the parameters for the avgsubsamp dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc avgsubsamp_init {} {
    global AvgsubsampVar
    
    set AvgsubsampVar(inimg,array) "none"
    set AvgsubsampVar(inimg,name) "none"
    set AvgsubsampVar(inimg,addr) "none"
    set AvgsubsampVar(lines) 2
    set AvgsubsampVar(pix) 2
    set AvgsubsampVar(incrlines) 2
    set AvgsubsampVar(incrpix) 2
    set AvgsubsampVar(outname) "Resamp"
}



#
# winsubsamp_dialog --
#
#       Create a dialog box for performing an window and subsample on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc winsubsamp_dialog { } {
    global WinsubsampVar
    global confirmStatus

    #
    # Determine the current image
    #
    set WinsubsampVar(inimg,array) [get_current_image]
    if {$WinsubsampVar(inimg,array) != "none"} {
	    upvar #0 $WinsubsampVar(inimg,array) imgarray
	    set WinsubsampVar(inimg,name) $imgarray(title)
	    set WinsubsampVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .winsubsampdlg]
    wm geometry $top +110+110
    wm title $top "Window and Subsample Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Window and Subsample on: "
    label $title.imglbl -fg blue -text $WinsubsampVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "From: "}
    lappend row {entry WinsubsampVar(from,band)}
    lappend row {label "Band   "}
    lappend row {entry WinsubsampVar(from,line)}
    lappend row {label "Line   "}
    lappend row {entry WinsubsampVar(from,pix)}
    lappend row {label "Pixel"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "To: "}
    lappend row {entry WinsubsampVar(to,band)}
    lappend row {label "Band   "}
    lappend row {entry WinsubsampVar(to,line)}
    lappend row {label "Line   "}
    lappend row {entry WinsubsampVar(to,pix)}
    lappend row {label "Pixel"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Increment: "}
    lappend row {entry WinsubsampVar(incr,band)}
    lappend row {label "Band(s) "}
    lappend row {entry WinsubsampVar(incr,line)}
    lappend row {label "Line(s) "}
    lappend row {entry WinsubsampVar(incr,pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable WinsubsampVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        winsubsamp_run    
    }
}
#
# winsubsamp_run --
#
#       Define a new region based on the parameters from the
#       winsubsamp dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc winsubsamp_run {} {
    global WinsubsampVar
    set out_sadie_addr [Sadie_Geometry_WinSub WinsubsampVar]
    create_display_image $WinsubsampVar(outname) $out_sadie_addr
}
#
# winsubsamp_init --
#
#       Initialize the parameters for the winsubsamp dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc winsubsamp_init {} {
    global WinsubsampVar
    
    set WinsubsampVar(inimg,array) "none"
    set WinsubsampVar(inimg,name) "none"
    set WinsubsampVar(inimg,addr) "none"
    set WinsubsampVar(from,band) 1
    set WinsubsampVar(from,line) 1
    set WinsubsampVar(from,pix) 1
    set WinsubsampVar(to,band) 3
    set WinsubsampVar(to,line) 256
    set WinsubsampVar(to,pix) 256
    set WinsubsampVar(incr,band) 1
    set WinsubsampVar(incr,line) 1
    set WinsubsampVar(incr,pix) 1
    set WinsubsampVar(outname) "Subsamp"
}





#
# linearscale_dialog --
#
#       Create a dialog box for performing a linear scale on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc linearscale_dialog { } {
    global LinearscaleVar
    global confirmStatus

    #
    # Determine the current image
    #
    set LinearscaleVar(inimg,array) [get_current_image]
    if {$LinearscaleVar(inimg,array) != "none"} {
	    upvar #0 $LinearscaleVar(inimg,array) imgarray
	    set LinearscaleVar(inimg,name) $imgarray(title)
	    set LinearscaleVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .linearscaledlg]
    wm geometry $top +110+110
    wm title $top "Scale Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Scale on: "
    label $title.imglbl -fg blue -text $LinearscaleVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Scale Factor: "}
    lappend row {entry LinearscaleVar(lines)}
    lappend row {label "Lines   "}
    lappend row {entry LinearscaleVar(pix)}
    lappend row {label "Pixels"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {interp_select LinearscaleVar(interp) LinearscaleVar(alpha) 1 3 1}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable LinearscaleVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        linearscale_run    
    }
}
#
# linearscale_run --
#
#       Define a new region based on the parameters from the
#       linearscale dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc linearscale_run {} {
    global LinearscaleVar

    switch $LinearscaleVar(interp) {
	1 { set LinearscaleVar(option) 1.0 }
	2 { set LinearscaleVar(option) 0.0 }
	3 { set LinearscaleVar(option) $LinearscaleVar(alpha) }
    }

    set out_sadie_addr [Sadie_Geometry_Scale LinearscaleVar]
    create_display_image $LinearscaleVar(outname) $out_sadie_addr
}
#
# linearscale_init --
#
#       Initialize the parameters for the linearscale dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc linearscale_init {} {
    global LinearscaleVar
    
    set LinearscaleVar(inimg,array) "none"
    set LinearscaleVar(inimg,name) "none"
    set LinearscaleVar(inimg,addr) "none"
    set LinearscaleVar(lines) 2.0
    set LinearscaleVar(pix) 2.0
    set LinearscaleVar(interp) 1
    set LinearscaleVar(alpha) -0.5
    set LinearscaleVar(option) 1.0
    set LinearscaleVar(outname) "Scale"
}




#
# rotate_dialog --
#
#       Create a dialog box for performing a rotation on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc rotate_dialog { } {
    global RotateVar
    global confirmStatus

    #
    # Determine the current image
    #
    set RotateVar(inimg,array) [get_current_image]
    if {$RotateVar(inimg,array) != "none"} {
	    upvar #0 $RotateVar(inimg,array) imgarray
	    set RotateVar(inimg,name) $imgarray(title)
	    set RotateVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .rotatedlg]
    wm geometry $top +110+110
    wm title $top "Rotate Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Rotation on: "
    label $title.imglbl -fg blue -text $RotateVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Rotation Angle: "}
    lappend row {entry RotateVar(angle)}
    lappend row {label "degrees"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Fill Graylevel: "}
    lappend row {entry RotateVar(graylevel)}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {interp_select RotateVar(interp) RotateVar(alpha) 1 3 1}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RotateVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        rotate_run    
    }
}
#
# rotate_run --
#
#       Define a new region based on the parameters from the
#       rotate dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc rotate_run {} {
    global RotateVar

    switch $RotateVar(interp) {
	1 { set RotateVar(option) 1.0 }
	2 { set RotateVar(option) 0.0 }
	3 { set RotateVar(option) $RotateVar(alpha) }
    }

    set out_sadie_addr [Sadie_Geometry_Rotate RotateVar]
    create_display_image $RotateVar(outname) $out_sadie_addr
}
#
# rotate_init --
#
#       Initialize the parameters for the rotate dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc rotate_init {} {
    global RotateVar
    
    set RotateVar(inimg,array) "none"
    set RotateVar(inimg,name) "none"
    set RotateVar(inimg,addr) "none"
    set RotateVar(angle) 90.0
    set RotateVar(graylevel) 0.0
    set RotateVar(interp) 1
    set RotateVar(alpha) -0.5
    set RotateVar(option) 1.0
    set RotateVar(outname) "Rotate"
}



#
# mirror_dialog --
#
#       Create a dialog box for performing a mirror on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc mirror_dialog { } {
    global MirrorVar
    global confirmStatus

    #
    # Determine the current image
    #
    set MirrorVar(inimg,array) [get_current_image]
    if {$MirrorVar(inimg,array) != "none"} {
	    upvar #0 $MirrorVar(inimg,array) imgarray
	    set MirrorVar(inimg,name) $imgarray(title)
	    set MirrorVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .mirrordlg]
    wm geometry $top +110+110
    wm title $top "Mirror Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Mirror on: "
    label $title.imglbl -fg blue -text $MirrorVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Mirror Axis: "}
    lappend row {radiobutton "Vertical" MirrorVar(option) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {skip}
    lappend row {radiobutton "-45 Degree Diagonal" MirrorVar(option) 1}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {skip}
    lappend row {radiobutton "+45 Degree Diagonal" MirrorVar(option) 2}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {skip}
    lappend row {radiobutton "Horizontal" MirrorVar(option) 3}
    dialog_create_stdrow $input 3 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable MirrorVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        mirror_run    
    }
}
#
# mirror_run --
#
#       Define a new region based on the parameters from the
#       mirror dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc mirror_run {} {
    global MirrorVar
    set out_sadie_addr [Sadie_Geometry_Mirror MirrorVar]
    create_display_image $MirrorVar(outname) $out_sadie_addr
}
#
# mirror_init --
#
#       Initialize the parameters for the mirror dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc mirror_init {} {
    global MirrorVar
    
    set MirrorVar(inimg,array) "none"
    set MirrorVar(inimg,name) "none"
    set MirrorVar(inimg,addr) "none"
    set MirrorVar(option) 0
    set MirrorVar(outname) "Mirror"
}



#
# controlpt_image_dialog --
#
#       Create a dialog box to query the following:
#           - Reference Image
#           - Transformation Image
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc controlpt_image_dialog {} {
    global SadieVar
    global ControlptVar
    global confirmStatus


    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .imgselectdlg]
    wm geometry $top +110+110
    wm title $top "Image Select Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Specify Control Point Images: "
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Reference Image: "}
    lappend row {imgchooser ControlptVar(refimg,addr) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Transformation Image: "}
    lappend row {imgchooser ControlptVar(transimg,addr) 1}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
	foreach img $SadieVar(imagelist) {
	    upvar #0 $img imgarray

	    if {$imgarray(sadie_addr) == $ControlptVar(refimg,addr)} {
		set ControlptVar(refimg,name) $imgarray(title)
	    }
	    if {$imgarray(sadie_addr) == $ControlptVar(transimg,addr)} {
		set ControlptVar(transimg,name) $imgarray(title)
	    }
	}
        controlpt_dialog    
    }


    destroy $top
}


#
# controlpt_dialog --
#
#       Create a dialog box for combining two images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc controlpt_dialog { } {
    global ControlptVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .controlptdlg]
    wm geometry $top +110+110
    wm title $top "Control Points Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Select Control Points"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    label $input.pairslbl -text "Number of Control Point Pairs: "
    radiobutton $input.pairsbtn3 -text 3 -variable ControlptVar(pointcount) -value 3 \
        -command "controlpt_update $input"
    radiobutton $input.pairsbtn4 -text 4 -variable ControlptVar(pointcount) -value 4 \
        -command "controlpt_update $input"
    radiobutton $input.pairsbtn5 -text 5 -variable ControlptVar(pointcount) -value 5 \
        -command "controlpt_update $input"
    radiobutton $input.pairsbtn6 -text 6 -variable ControlptVar(pointcount) -value 6 \
        -command "controlpt_update $input"

    label $input.translbl -text "Transformation Image: "
    label $input.transimglbl -text $ControlptVar(transimg,name) -relief ridge
    label $input.transxlbl -text "x = "
    label $input.transylbl -text "y = "
    label $input.transbtnlbl -text "Select Control Points: "

    entry $input.transxent1 -width 5 -textvariable ControlptVar(trans,x,1)
    entry $input.transyent1 -width 5 -textvariable ControlptVar(trans,y,1)
    create_ctrlpt_selector $input.transbtn1 ControlptVar "trans,x,1" "trans,y,1" $ControlptVar(transimg,name)
    entry $input.transxent2 -width 5 -textvariable ControlptVar(trans,x,2)
    entry $input.transyent2 -width 5 -textvariable ControlptVar(trans,y,2)
    create_ctrlpt_selector $input.transbtn2 ControlptVar "trans,x,2" "trans,y,2" $ControlptVar(transimg,name)
    entry $input.transxent3 -width 5 -textvariable ControlptVar(trans,x,3)
    entry $input.transyent3 -width 5 -textvariable ControlptVar(trans,y,3)
    create_ctrlpt_selector $input.transbtn3 ControlptVar "trans,x,3" "trans,y,3" $ControlptVar(transimg,name)
    entry $input.transxent4 -width 5 -textvariable ControlptVar(trans,x,4)
    entry $input.transyent4 -width 5 -textvariable ControlptVar(trans,y,4)
    create_ctrlpt_selector $input.transbtn4 ControlptVar "trans,x,4" "trans,y,4" $ControlptVar(transimg,name)
    entry $input.transxent5 -width 5 -textvariable ControlptVar(trans,x,5)
    entry $input.transyent5 -width 5 -textvariable ControlptVar(trans,y,5)
    create_ctrlpt_selector $input.transbtn5 ControlptVar "trans,x,5" "trans,y,5" $ControlptVar(transimg,name)
    entry $input.transxent6 -width 5 -textvariable ControlptVar(trans,x,6)
    entry $input.transyent6 -width 5 -textvariable ControlptVar(trans,y,6)
    create_ctrlpt_selector $input.transbtn6 ControlptVar "trans,x,6" "trans,y,6" $ControlptVar(transimg,name)

    label $input.reflbl -text "Reference Image: "
    label $input.refimglbl -text $ControlptVar(refimg,name) -relief ridge
    label $input.refxlbl -text "xref = "
    label $input.refylbl -text "yref = "
    label $input.refbtnlbl -text "Select Control Points: "
    entry $input.refxent1 -width 5 -textvariable ControlptVar(ref,x,1)
    entry $input.refyent1 -width 5 -textvariable ControlptVar(ref,y,1)
    create_ctrlpt_selector $input.refbtn1 ControlptVar "ref,x,1" "ref,y,1" $ControlptVar(refimg,name)
    entry $input.refxent2 -width 5 -textvariable ControlptVar(ref,x,2)
    entry $input.refyent2 -width 5 -textvariable ControlptVar(ref,y,2)
    create_ctrlpt_selector $input.refbtn2 ControlptVar "ref,x,2" "ref,y,2" $ControlptVar(refimg,name)
    entry $input.refxent3 -width 5 -textvariable ControlptVar(ref,x,3)
    entry $input.refyent3 -width 5 -textvariable ControlptVar(ref,y,3)
    create_ctrlpt_selector $input.refbtn3 ControlptVar "ref,x,3" "ref,y,3" $ControlptVar(refimg,name)
    entry $input.refxent4 -width 5 -textvariable ControlptVar(ref,x,4)
    entry $input.refyent4 -width 5 -textvariable ControlptVar(ref,y,4)
    create_ctrlpt_selector $input.refbtn4 ControlptVar "ref,x,4" "ref,y,4" $ControlptVar(refimg,name)
    entry $input.refxent5 -width 5 -textvariable ControlptVar(ref,x,5)
    entry $input.refyent5 -width 5 -textvariable ControlptVar(ref,y,5)
    create_ctrlpt_selector $input.refbtn5 ControlptVar "ref,x,5" "ref,y,5" $ControlptVar(refimg,name)
    entry $input.refxent6 -width 5 -textvariable ControlptVar(ref,x,6)
    entry $input.refyent6 -width 5 -textvariable ControlptVar(ref,y,6)
    create_ctrlpt_selector $input.refbtn6 ControlptVar "ref,x,6" "ref,y,6" $ControlptVar(refimg,name)

    label $input.termslbl -text "Number of Polynomial Terms: " -justify left
    radiobutton $input.termsbtn3 -text 3 -variable ControlptVar(termcount) -value 3
    radiobutton $input.termsbtn4 -text 4 -variable ControlptVar(termcount) -value 4
    radiobutton $input.termsbtn5 -text 5 -variable ControlptVar(termcount) -value 5
    radiobutton $input.termsbtn6 -text 6 -variable ControlptVar(termcount) -value 6
    
    frame $input.frame1 -height 2 -relief sunken -borderwidth 2 
    frame $input.frame2 -height 2 -relief sunken -borderwidth 2

    grid $input.pairslbl -row 0 -column 0 -columnspan 3 -sticky w
    grid $input.pairsbtn3 -row 0 -column 3 -sticky news
    grid $input.pairsbtn4 -row 0 -column 4 -sticky news
    grid $input.pairsbtn5 -row 0 -column 5 -sticky news
    grid $input.pairsbtn6 -row 0 -column 6 -sticky news

    grid $input.termslbl -row 1 -column 0 -columnspan 3 -sticky w
    grid $input.termsbtn3 -row 1 -column 3 -sticky news
    grid $input.termsbtn4 -row 1 -column 4 -sticky news
    grid $input.termsbtn5 -row 1 -column 5 -sticky news
    grid $input.termsbtn6 -row 1 -column 6 -sticky news

    grid $input.frame1 -row 2 -column 0 -columnspan 7 -pady 5 -sticky news
    grid $input.translbl -row 3 -column 0 -sticky w
    grid $input.transimglbl -row 3 -column 1 -columnspan 6 -sticky w -ipadx 2

    grid $input.transxlbl -row 4 -column 0 -sticky w
    grid $input.transxent1 -row 4 -column 1 -sticky w
    grid $input.transxent2 -row 4 -column 2 -sticky w
    grid $input.transxent3 -row 4 -column 3 -sticky w
    grid $input.transxent4 -row 4 -column 4 -sticky w
    grid $input.transxent5 -row 4 -column 5 -sticky w
    grid $input.transxent6 -row 4 -column 6 -sticky w

    grid $input.transylbl -row 5 -column 0 -sticky w
    grid $input.transyent1 -row 5 -column 1 -sticky w
    grid $input.transyent2 -row 5 -column 2 -sticky w
    grid $input.transyent3 -row 5 -column 3 -sticky w
    grid $input.transyent4 -row 5 -column 4 -sticky w
    grid $input.transyent5 -row 5 -column 5 -sticky w
    grid $input.transyent6 -row 5 -column 6 -sticky w

    grid $input.transbtnlbl -row 6 -column 0 -sticky w
    grid $input.transbtn1 -row 6 -column 1 -pady 4 -sticky ew
    grid $input.transbtn2 -row 6 -column 2 -pady 4 -sticky ew
    grid $input.transbtn3 -row 6 -column 3 -pady 4 -sticky ew
    grid $input.transbtn4 -row 6 -column 4 -pady 4 -sticky ew
    grid $input.transbtn5 -row 6 -column 5 -pady 4 -sticky ew
    grid $input.transbtn6 -row 6 -column 6 -pady 4 -sticky ew

    grid $input.frame2 -row 7 -column 0 -columnspan 7 -pady 5 -sticky news

    grid $input.reflbl -row 8 -column 0 -sticky w
    grid $input.refimglbl -row 8 -column 1 -columnspan 6 -sticky w -ipadx 2
    
    grid $input.refxlbl -row 9 -column 0 -sticky w
    grid $input.refxent1 -row 9 -column 1 -sticky w
    grid $input.refxent2 -row 9 -column 2 -sticky w
    grid $input.refxent3 -row 9 -column 3 -sticky w
    grid $input.refxent4 -row 9 -column 4 -sticky w
    grid $input.refxent5 -row 9 -column 5 -sticky w
    grid $input.refxent6 -row 9 -column 6 -sticky w

    grid $input.refylbl -row 10 -column 0 -sticky w
    grid $input.refyent1 -row 10 -column 1 -sticky w
    grid $input.refyent2 -row 10 -column 2 -sticky w
    grid $input.refyent3 -row 10 -column 3 -sticky w
    grid $input.refyent4 -row 10 -column 4 -sticky w
    grid $input.refyent5 -row 10 -column 5 -sticky w
    grid $input.refyent6 -row 10 -column 6 -sticky w

    grid $input.refbtnlbl -row 11 -column 0 -sticky w
    grid $input.refbtn1 -row 11 -column 1 -pady 4 -sticky ew
    grid $input.refbtn2 -row 11 -column 2 -pady 4 -sticky ew
    grid $input.refbtn3 -row 11 -column 3 -pady 4 -sticky ew
    grid $input.refbtn4 -row 11 -column 4 -pady 4 -sticky ew
    grid $input.refbtn5 -row 11 -column 5 -pady 4 -sticky ew
    grid $input.refbtn6 -row 11 -column 6 -pady 4 -sticky ew

    grid columnconfigure $input 0 -weight 1
    grid rowconfigure $input 5 -minsize 10

    controlpt_update $input
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top

    if {$confirmStatus == 1} {
        controlpt_run    
    }


}
proc controlpt_update {win} {
    global ControlptVar

    if {$ControlptVar(pointcount) < $ControlptVar(termcount)} {
	set ControlptVar(termcount) $ControlptVar(pointcount)
    }
    
    for {set i 4} {$i <= 6} {incr i} {
	if {$ControlptVar(pointcount) >= $i} {
	    $win.refxent$i configure -state normal -fg black
	    $win.refyent$i configure -state normal -fg black
	    $win.refbtn$i configure -state normal -fg Blue
	    $win.transxent$i configure -state normal -fg black
	    $win.transyent$i configure -state normal -fg black
	    $win.transbtn$i configure -state normal -fg Blue
	    $win.termsbtn$i configure -state normal -fg black
	} else {
	    set fgcolor [$win.refxent$i cget -bg]
	    $win.refxent$i configure -state disabled -fg $fgcolor
	    $win.refyent$i configure -state disabled -fg $fgcolor
	    $win.refbtn$i configure -state disabled -fg $fgcolor
	    $win.transxent$i configure -state disabled -fg $fgcolor
	    $win.transyent$i configure -state disabled -fg $fgcolor
	    $win.transbtn$i configure -state disabled -fg $fgcolor
	    $win.termsbtn$i configure -state disabled -fg $fgcolor
	}
    }
}
#
# controlpt_run --
#
#       Create a controlptd image based on the parameters from the
#       controlpt dialog.
#
# Arguments:
#       None
#
# Results:
#       The controlptd image is created and displayed.
#
proc controlpt_run {} {
    global ControlptVar SadieVar
    
    Sadie_Geometry_ContPts ControlptVar
}
#
# controlpt_init --
#
#       Initialize the parameters for the controlpt dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc controlpt_init {} {
    global ControlptVar
    
    set ControlptVar(pointcount) 3
    set ControlptVar(termcount) 3

    set ControlptVar(trans,x,1) 0.0
    set ControlptVar(trans,y,1) 0.0
    set ControlptVar(trans,x,2) 0.0
    set ControlptVar(trans,y,2) 0.0
    set ControlptVar(trans,x,3) 0.0
    set ControlptVar(trans,y,3) 0.0
    set ControlptVar(trans,x,4) 0.0
    set ControlptVar(trans,y,4) 0.0
    set ControlptVar(trans,x,5) 0.0
    set ControlptVar(trans,y,5) 0.0
    set ControlptVar(trans,x,6) 0.0
    set ControlptVar(trans,y,6) 0.0

    set ControlptVar(ref,x,1) 0.0
    set ControlptVar(ref,y,1) 0.0
    set ControlptVar(ref,x,2) 0.0
    set ControlptVar(ref,y,2) 0.0
    set ControlptVar(ref,x,3) 0.0
    set ControlptVar(ref,y,3) 0.0
    set ControlptVar(ref,x,4) 0.0
    set ControlptVar(ref,y,4) 0.0
    set ControlptVar(ref,x,5) 0.0
    set ControlptVar(ref,y,5) 0.0
    set ControlptVar(ref,x,6) 0.0
    set ControlptVar(ref,y,6) 0.0
}






#
# polywarp_dialog --
#
#       Create a dialog box for performing a polynomial warp on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc polywarp_dialog { } {
    global PolywarpVar
    global confirmStatus

    #
    # Determine the current image
    #
    set PolywarpVar(inimg,array) [get_current_image]
    if {$PolywarpVar(inimg,array) != "none"} {
	upvar #0 $PolywarpVar(inimg,array) imgarray
	set PolywarpVar(inimg,name) $imgarray(title)
	set PolywarpVar(inimg,addr) $imgarray(sadie_addr)
	set PolywarpVar(lines) [Sadie_General_Height $imgarray(sadie_addr)]
	set PolywarpVar(pix) [Sadie_General_Width $imgarray(sadie_addr)]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .polywarpdlg]
    wm geometry $top +110+110
    wm title $top "Polynomial Warp Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Polynomial Warp on: "
    label $title.imglbl -fg blue -text $PolywarpVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry PolywarpVar(lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry PolywarpVar(pix)}
    lappend row {label "Pixels"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Fill Graylevel: "}
    lappend row {entry PolywarpVar(graylevel)}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {interp_select PolywarpVar(interp) PolywarpVar(alpha) 1 3 1}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable PolywarpVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        polywarp_run    
    }
}
#
# polywarp_run --
#
#       Define a new region based on the parameters from the
#       polywarp dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc polywarp_run {} {
    global PolywarpVar

    switch $PolywarpVar(interp) {
	1 { set PolywarpVar(option) 1.0 }
	2 { set PolywarpVar(option) 0.0 }
	3 { set PolywarpVar(option) $PolywarpVar(alpha) }
    }

    set out_sadie_addr [Sadie_Geometry_GeomWarp PolywarpVar]
    create_display_image $PolywarpVar(outname) $out_sadie_addr
}
#
# polywarp_init --
#
#       Initialize the parameters for the polywarp dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc polywarp_init {} {
    global PolywarpVar
    
    set PolywarpVar(inimg,array) "none"
    set PolywarpVar(inimg,name) "none"
    set PolywarpVar(inimg,addr) "none"
    set PolywarpVar(lines) 64
    set PolywarpVar(pix) 64
    set PolywarpVar(graylevel) 0.0    
    set PolywarpVar(interp) 1
    set PolywarpVar(alpha) -0.5
    set PolywarpVar(option) 1.0
    set PolywarpVar(outname) "Warp"
}



#
# horizmosaic_dialog --
#
#       Create a dialog box for performing a horizontal mosaic with two display
#       images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc horizmosaic_dialog { } {
    global HorizmosaicVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .horizmosaicdlg]
    wm geometry $top +110+110
    wm title $top "Horizontal Mosaic Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a Horizontal Mosaic"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Left Image: "}
    lappend row {imgchooser HorizmosaicVar(inimg,addr1) 0 2}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Right Image: "}
    lappend row {imgchooser HorizmosaicVar(inimg,addr2) 1 2}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Vertical Offset: "}
    lappend row {entry HorizmosaicVar(offset)}
    lappend row {label "Line(s)"}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label "Fill Graylevel: "}
    lappend row {entry HorizmosaicVar(fill)}
    dialog_create_stdrow $input 3 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable HorizmosaicVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        horizmosaic_run    
    }
}
#
# horizmosaic_run --
#
#       Define a new region based on the parameters from the
#       horizmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc horizmosaic_run {} {
    global HorizmosaicVar
    set out_sadie_addr [Sadie_Geometry_HMosaic HorizmosaicVar]
    create_display_image $HorizmosaicVar(outname) $out_sadie_addr
}
#
# horizmosaic_init --
#
#       Initialize the parameters for the horizmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc horizmosaic_init {} {
    global HorizmosaicVar
    
    set HorizmosaicVar(inimg,addr1) "none"
    set HorizmosaicVar(inimg,addr2) "none"
    set HorizmosaicVar(offset) 0
    set HorizmosaicVar(fill) 0.0
    set HorizmosaicVar(outname) "HMosaic"
}




#
# vertmosaic_dialog --
#
#       Create a dialog box for performing a vertical mosaic with two display
#       images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc vertmosaic_dialog { } {
    global VertmosaicVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .vertmosaicdlg]
    wm geometry $top +110+110
    wm title $top "Vertical Mosaic Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a Vertical Mosaic"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Top Image: "}
    lappend row {imgchooser VertmosaicVar(inimg,addr1) 0 2}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Bottom Image: "}
    lappend row {imgchooser VertmosaicVar(inimg,addr2) 1 2}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Vertical Offset: "}
    lappend row {entry VertmosaicVar(offset)}
    lappend row {label "Line(s)"}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label "Fill Graylevel: "}
    lappend row {entry VertmosaicVar(fill)}
    dialog_create_stdrow $input 3 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable VertmosaicVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        vertmosaic_run    
    }
}
#
# vertmosaic_run --
#
#       Define a new region based on the parameters from the
#       vertmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc vertmosaic_run {} {
    global VertmosaicVar
    set out_sadie_addr [Sadie_Geometry_VMosaic VertmosaicVar]
    create_display_image $VertmosaicVar(outname) $out_sadie_addr
}
#
# vertmosaic_init --
#
#       Initialize the parameters for the vertmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc vertmosaic_init {} {
    global VertmosaicVar
    
    set VertmosaicVar(inimg,addr1) "none"
    set VertmosaicVar(inimg,addr2) "none"
    set VertmosaicVar(offset) 0
    set VertmosaicVar(fill) 0.0
    set VertmosaicVar(outname) "VMosaic"
}





#
# genmosaic_dialog --
#
#       Create a dialog box for performing a general mosaic with two display
#       images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc genmosaic_dialog { } {
    global GenmosaicVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .genmosaicdlg]
    wm geometry $top +110+110
    wm title $top "General Mosaic Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform a General Mosaic"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry GenmosaicVar(lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry GenmosaicVar(pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "First Image: "}
    lappend row {imgchooser GenmosaicVar(inimg,addr1) 0 4}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Offset: "}
    lappend row {entry GenmosaicVar(offset1,lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry GenmosaicVar(offset1,pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 2 $row

    set row {}
    lappend row {label "Second Image: "}
    lappend row {imgchooser GenmosaicVar(inimg,addr2) 1 4}
    dialog_create_stdrow $input 3 $row

    set row {}
    lappend row {label "Offset: "}
    lappend row {entry GenmosaicVar(offset2,lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry GenmosaicVar(offset2,pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 4 $row

    set row {}
    lappend row {label "Fill Graylevel: "}
    lappend row {entry GenmosaicVar(fill)}
    dialog_create_stdrow $input 5 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable GenmosaicVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        genmosaic_run    
    }
}
#
# genmosaic_run --
#
#       Define a new region based on the parameters from the
#       genmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc genmosaic_run {} {
    global GenmosaicVar
    set out_sadie_addr [Sadie_Geometry_GenMosaic GenmosaicVar]
    create_display_image $GenmosaicVar(outname) $out_sadie_addr
}
#
# genmosaic_init --
#
#       Initialize the parameters for the genmosaic dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc genmosaic_init {} {
    global GenmosaicVar
    
    set GenmosaicVar(inimg,addr1) "none"
    set GenmosaicVar(inimg,addr1) "none"
    set GenmosaicVar(lines) 64
    set GenmosaicVar(pix) 64
    set GenmosaicVar(offset1,lines) 0
    set GenmosaicVar(offset1,pix) 0
    set GenmosaicVar(offset2,lines) 32
    set GenmosaicVar(offset2,pix) 32
    set GenmosaicVar(fill) 0.0
    set GenmosaicVar(outname) "Mosaic"
}






#
# insert_dialog --
#
#       Create a dialog box for performing an insert with two display
#       images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc insert_dialog { } {
    global InsertVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .insertdlg]
    wm geometry $top +110+110
    wm title $top "Insert Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Insert an Image into Another"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Background Image: "}
    lappend row {imgchooser InsertVar(inimg,addr1) 0 4}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Foreground Image: "}
    lappend row {imgchooser InsertVar(inimg,addr2) 1 4}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Offset: "}
    lappend row {entry InsertVar(offset,lines)}
    lappend row {label "Line(s)   "}
    lappend row {entry InsertVar(offset,pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable InsertVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus

    destroy $top
    
    if {$confirmStatus == 1} {
        insert_run    
    }
}
#
# insert_run --
#
#       Define a new region based on the parameters from the
#       insert dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc insert_run {} {
    global InsertVar
    set out_sadie_addr [Sadie_Geometry_Insert InsertVar]
    create_display_image $InsertVar(outname) $out_sadie_addr
}
#
# insert_init --
#
#       Initialize the parameters for the insert dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc insert_init {} {
    global InsertVar
    
    set InsertVar(inimg,addr1) "none"
    set InsertVar(inimg,addr2) "none"
    set InsertVar(offset,lines) 0
    set InsertVar(offset,pix) 0
    set InsertVar(outname) "Insert"
}



