# proc Library_UpdateIndex { libdir } 
# proc create_main_gui {} 
# proc create_sessionlog_gui {} 
# proc update_sessionlog { varName index operation} 
# proc update_sessionlog_view {} 
# proc Canvas_EditBind { c } 
# proc CanvasTextHit {c x y {select 1}} 
# proc CanvasTextDrag {c x y} 
# proc set_shape_tool {shape} 
# proc register_canvas_info { canvas object statusmesg } 
# proc register_window_info { win statusmesg } 
# proc update_gui {} 
# proc exit_tclSadie {} 
# proc tclSadie_main_init {} 
# proc tclSadie_proto_init {} 
# proc set_default_parameters {} 



#
# Library_UpdateIndex --
#
#       Update the tclIndex file if necessary.
#
# Arguments:
#       libdir -- the tcl library directory to update
#
# Results:
#       This procedure updates the tclIndex file in a directory
#       containing tcl files.  This allows a tcl program
#       to be broken into multiple files.
#
proc Library_UpdateIndex { libdir } {
	set index [file join $libdir tclIndex]
	if ![file exists $index] {
		set doit 1
	} else {
		set age [file mtime $index]
		set doit 0
		# Changes to directory may mean files were deleted
		if {[file mtime $libdir] > $age} {
			set doit 1
		} else {
			# Check each file for modification
			foreach file [glob [file join $libdir *.tcl]] {
				if {[file mtime $file] > $age} {
					set doit 1
					break
				}
			}
		}
	}
	if { $doit } {
		auto_mkindex $libdir *.tcl
	}
}


#
# create_main_gui --
#
#       Build the tclSadie interface.
#
# Arguments:
#       none
#
# Results:
#       This procedure builds the gui and displays it to the screen
#
proc create_main_gui {} {
    global SadieVar
    wm positionfrom . user
    wm geometry . +50+50
    wm protocol . WM_DELETE_WINDOW { exit_tclSadie }
    wm title . $SadieVar(version)

    #
    # Create menubar
    #
    frame .menubar -bd 1 -relief raised
    pack .menubar -side top -fill x
    
    set SadieVar(button,file) .menubar.file
    set SadieVar(menu,file) $SadieVar(button,file).menu
    set SadieVar(button,edit) .menubar.edit
    set SadieVar(menu,edit) $SadieVar(button,edit).menu
    set SadieVar(button,contrast) .menubar.contrast
    set SadieVar(menu,contrast) $SadieVar(button,contrast).menu
    set SadieVar(button,filter) .menubar.filter
    set SadieVar(menu,filter) $SadieVar(button,filter).menu
    set SadieVar(button,geometry) .menubar.geometry
    set SadieVar(menu,geometry) $SadieVar(button,geometry).menu
    set SadieVar(button,multi) .menubar.multi
    set SadieVar(menu,multi) $SadieVar(button,multi).menu
    set SadieVar(button,classify) .menubar.classify
    set SadieVar(menu,classify) $SadieVar(button,classify).menu
    set SadieVar(button,tools) .menubar.tools
    set SadieVar(menu,tools) $SadieVar(button,tools).menu
    set SadieVar(button,winlist) .menubar.winlist
    set SadieVar(menu,winlist) $SadieVar(button,winlist).menu
    set SadieVar(button,help) .menubar.help
    set SadieVar(menu,help) $SadieVar(button,help).menu
    create_menus
    
    
    #
    # Frame for everything under menubar
    #
    frame .main -bd 0

    frame .main.left -relief flat -bd 3

    label .main.left.imglabel -text "Current Image:" -anchor w
    set SadieVar(label,currentimg) "None"
    message .main.left.theimg -width 200 -textvariable SadieVar(label,currentimg) \
      -anchor w -fg RoyalBlue
    pack .main.left.imglabel .main.left.theimg -side top -fill x

    frame .main.left.output -relief groove -borderwidth 3
    frame .main.left.output.coordinates
    label .main.left.output.coordinates.label -text "Coordinates:" -anchor w
    set SadieVar(label,xpos) " X: "
    set SadieVar(label,ypos) " Y: "
    label .main.left.output.coordinates.xcoord \
        -textvariable SadieVar(label,xpos) -anchor w
    label .main.left.output.coordinates.ycoord \
        -textvariable SadieVar(label,ypos) -anchor w
    pack .main.left.output.coordinates.label .main.left.output.coordinates.xcoord \
      .main.left.output.coordinates.ycoord \
        -side top -fill x

    frame .main.left.output.sadie
    label .main.left.output.sadie.label -text "Sadie Pixel Value:" -anchor w
    set SadieVar(label,s_rval) " Z: "
    set SadieVar(label,s_gval) "   "
    set SadieVar(label,s_bval) "   "
    label .main.left.output.sadie.rout \
        -textvariable SadieVar(label,s_rval) -anchor w
    label .main.left.output.sadie.gout \
        -textvariable SadieVar(label,s_gval) -anchor w
    label .main.left.output.sadie.bout \
        -textvariable SadieVar(label,s_bval) -anchor w
    pack .main.left.output.sadie.label .main.left.output.sadie.rout \
      .main.left.output.sadie.gout .main.left.output.sadie.bout \
        -side top -fill x

    frame .main.left.output.display
    label .main.left.output.display.label -text "Display:" -anchor w
    set SadieVar(label,d_rval) " Z: "
    set SadieVar(label,d_gval) "   "
    set SadieVar(label,d_bval) "   "
    label .main.left.output.display.rout \
        -textvariable SadieVar(label,d_rval) -anchor w
    label .main.left.output.display.gout \
        -textvariable SadieVar(label,d_gval) -anchor w
    label .main.left.output.display.bout \
        -textvariable SadieVar(label,d_bval) -anchor w
    pack .main.left.output.display.label .main.left.output.display.rout \
      .main.left.output.display.gout .main.left.output.display.bout \
        -side top -fill x

    pack .main.left.output.coordinates .main.left.output.sadie \
      .main.left.output.display \
        -side left -fill y -padx 5
    pack .main.left.output -side bottom -fill x



    frame .main.middle -relief raised -bd 3

    frame .main.middle.zoom
    button .main.middle.zoom.minus -text "-" -command zoom_out
    register_window_info .main.middle.zoom.minus "Zoom Out on the Current Image"
    button .main.middle.zoom.plus -text "+" -command zoom_in
    register_window_info .main.middle.zoom.plus "Zoom In on the Current Image"
    label .main.middle.zoom.label -text "  Zoom  "
    set SadieVar(label,zoom) ""
    label .main.middle.zoom.value -textvariable SadieVar(label,zoom) -fg Red

    grid .main.middle.zoom.minus -row 0 -column 0 -rowspan 2 -sticky news
    grid .main.middle.zoom.plus  -row 0 -column 2 -rowspan 2 -sticky news
    grid .main.middle.zoom.label -row 0 -column 1 -rowspan 1 -sticky news
    grid .main.middle.zoom.value -row 1 -column 1 -rowspan 1 -sticky news

    frame .main.middle.center
    set SadieVar(getstretched) 1
    set SadieVar(button,scaling) .main.middle.center.scaling
    checkbutton $SadieVar(button,scaling) -text "Scaling" \
      -variable SadieVar(getstretched) -onvalue 1 -offvalue 0 \
      -command change_scaling -anchor w
    register_window_info $SadieVar(button,scaling) "Toggle to (Un)Display a Scaled Version of Image"

    set SadieVar(showregions) 0
    set SadieVar(button,regions) .main.middle.center.regions
    checkbutton $SadieVar(button,regions) -text "Show Regions" \
        -variable SadieVar(showregions) -onvalue 1 -offvalue 0 \
	-state disabled -anchor w -command change_showregions
    register_window_info $SadieVar(button,regions) "Toggle to (Un)Display Defined Regions"

    set SadieVar(showctrlpts) 1
    set SadieVar(button,ctrlpts) .main.middle.center.ctrlpts
    checkbutton $SadieVar(button,ctrlpts) -text "Show Control Points" \
        -variable SadieVar(showctrlpts) -onvalue 1 -offvalue 0 \
	-state normal -anchor w -command change_showctrlpts
    register_window_info $SadieVar(button,ctrlpts) "Toggle to (Un)Display Defined Control Points"
    pack .main.middle.center.scaling .main.middle.center.regions .main.middle.center.ctrlpts\
        -side top -fill x

    set SadieVar(button,statistics) .main.middle.stats
    button $SadieVar(button,statistics) -text "Statistics" -command statistics_dialog -state disabled
    register_window_info $SadieVar(button,statistics) "Statistics Tool"

    pack .main.middle.zoom \
        -side top -fill x -pady 5
    pack .main.middle.center \
        -side top -fill x -padx 10 -pady 5
    pack .main.middle.stats \
        -side top -fill x -padx 10 -pady 5

    frame .main.right -relief flat -bd 3

    image create bitmap rectbutton -file $SadieVar(libdir)/rectbox.xbm
    image create bitmap pointbutton -file $SadieVar(libdir)/pointbox.xbm
    image create bitmap linebutton -file $SadieVar(libdir)/linebox.xbm
    image create bitmap polybutton -file $SadieVar(libdir)/polybox.xbm
    image create bitmap checkmark -file $SadieVar(libdir)/check.xbm
    image create bitmap blank -file $SadieVar(libdir)/blank.xbm
    image create bitmap point -file $SadieVar(libdir)/point.xbm

    set SadieVar(button,rectangle) .main.right.rect
    set SadieVar(button,point) .main.right.point
    set SadieVar(button,line) .main.right.line
    set SadieVar(button,poly) .main.right.poly
    
    button $SadieVar(button,rectangle) -image rectbutton \
	    -command "set_shape_tool rectangle"
    register_window_info $SadieVar(button,rectangle) "Extraction Tool"
    button $SadieVar(button,point) -image pointbutton \
	    -command "set_shape_tool point"
    register_window_info $SadieVar(button,point) "Control Point Tool"
    button $SadieVar(button,line) -image linebutton \
	    -command "set_shape_tool line"
    register_window_info $SadieVar(button,line) "Profile Tool"
    button $SadieVar(button,poly) -image polybutton \
	    -command "set_shape_tool poly"
    register_window_info $SadieVar(button,poly) "Region Tool"

    pack $SadieVar(button,rectangle) $SadieVar(button,point) \
	    $SadieVar(button,line) $SadieVar(button,poly) \
	    -side top -fill both -padx 2

    $SadieVar(button,rectangle) configure -activebackground gray
    $SadieVar(button,point) configure -activebackground gray
    $SadieVar(button,line) configure -activebackground gray
    $SadieVar(button,poly) configure -activebackground gray
    $SadieVar(button,rectangle) invoke

    frame .bottom
    label .bottom.info -relief sunken -textvariable SadieVar(label,info) -anchor w
    pack .bottom.info -side left -fill both -expand 1 -padx 1 -pady 1
    
    pack .main.left .main.middle .main.right -side left -fill y
    pack .main .bottom -side top -fill x

}

#
# create_sessionlog_gui --
#
#       Create the tclSadie sessionlog.
#
# Arguments:
#       none
#
# Results:
#       This sessionlog is created and displayed to the screen.
#
proc create_sessionlog_gui {} {
    global SadieVar
    
    toplevel .sessionlog
    wm title .sessionlog "Session Log"
    wm geometry .sessionlog +50+400
    wm protocol .sessionlog WM_DELETE_WINDOW { 
	tk_dialog .dlg \
		"Warning" "Printable Session Log must remain open!" warning 0 OK
    }
    canvas .sessionlog.canvas \
	    -yscrollcommand ".sessionlog.yscrl set" \
	    -xscrollcommand ".sessionlog.xscrl set" \
	    -width 500 \
	    -height 150 \
	    -scrollregion "0 0 500 150"
    scrollbar .sessionlog.yscrl -command ".sessionlog.canvas yview"
    scrollbar .sessionlog.xscrl -command ".sessionlog.canvas xview" -orient horizontal

    grid .sessionlog.canvas .sessionlog.yscrl -sticky news
    grid .sessionlog.xscrl -sticky ew
    grid rowconfigure .sessionlog 0 -weight 1
    grid columnconfigure .sessionlog 0 -weight 1

    Canvas_EditBind .sessionlog.canvas

    trace variable SadieVar(message) w update_sessionlog
}

#
# update_sessionlog --
#
#       Update the tclSadie sessionlog with new text.
#
# Arguments:
#       varName -- The name of the variable containing the new text.
#       index -- The index of the variable, if it exists.
#       operation -- How the variable was accessed to generate trace.
#
# Results:
#       New text is added to the sessionlog.  This procedure is called
#       whenever a traced variable is written to.
#
proc update_sessionlog { varName index operation} {
    global SadieVar
    
    upvar #0 $varName var

    set lastobj [.sessionlog.canvas find closest 0 $SadieVar(sessionlog,pos)]
    set lastobjtags [.sessionlog.canvas gettags $lastobj]

    if {[lsearch $lastobjtags "text"] != -1} {
	#The last object was text

	set thetext [.sessionlog.canvas itemcget $lastobj -text]
	append thetext "\n$var($index)"
	.sessionlog.canvas itemconfigure $lastobj -text $thetext
    } else {
	#The last object was NOT text
	# Add the new message to the sessionlog
	set lastobj [.sessionlog.canvas create text 5 $SadieVar(sessionlog,pos) -text $var($index) -tags text -justify left -anchor nw -font fixed]
    }


    set templist [.sessionlog.canvas bbox $lastobj]
    set SadieVar(sessionlog,pos) [lindex $templist 3]

    update_sessionlog_view
}

#
# update_sessionlog_view --
#
#       Update the tclSadie sessionlog view.
#
# Arguments:
#       none
#
# Results:
#       This procedure should be called after new content is added
#       to the sessionlog.  It moves the view to the bottom-left
#       corner.
#
proc update_sessionlog_view {} {
    global SadieVar

    set w [.sessionlog.canvas cget -width]
    set h [.sessionlog.canvas cget -height]
    foreach {x1 y1 x2 y2} [.sessionlog.canvas bbox all] {}
    set maxx [expr ($w > $x2)?$w:$x2]
    set maxy [expr ($h > $y2)?$h:$y2]

    .sessionlog.canvas configure -scrollregion "0 0 $maxx $maxy"

    .sessionlog.canvas xview moveto 0
    .sessionlog.canvas yview moveto 1
}


proc Canvas_EditBind { c } {
#    bind $c <Button-1> {
#	CanvasFocus %W [%W canvasx %x] [%W canvasy %y]
#    }
    $c bind text <Button-1> \
	    {CanvasTextHit %W [%W canvasx %x] [%W canvasy %y]}
    $c bind text <B1-Motion> \
	    {CanvasTextDrag %W [%W canvasx %x] [%W canvasy %y]}
}

#proc CanvasFocus {c x y} {
#    focus $c
#    set id [$c find overlapping [expr $x-2] [expr $y-2] \
#	    [expr $x+2] [expr $y+2]]
#    if {($id == {}) || ([$c type $id] != "text")} {
#	set t [$c create text $x $y -text "" \
#		-tags text -anchor nw]
#	$c focus $t
#	$c select clear
#	$c icursor $t 0
#	$c select from $t 0
#    }
#}

proc CanvasTextHit {c x y {select 1}} {
    $c focus current
    $c icursor current @$x,$y
    $c select clear
    $c select from current @$x,$y
}

proc CanvasTextDrag {c x y} {
    $c select to current @$x,$y
}



#
# set_shape_tool --
#
#       Change the selected shape drawing tool.
#
# Arguments:
#       shape -- The shape to change to.
#
# Results:
#       Update the appearance of the shape tool buttons
#       to indicate the currently selected shape.
#
proc set_shape_tool {shape} {
    global SadieVar

    $SadieVar(button,rectangle) configure -relief raised
    $SadieVar(button,point) configure -relief raised
    $SadieVar(button,line) configure -relief raised
    $SadieVar(button,poly) configure -relief raised
      
    $SadieVar(button,rectangle) configure -bg [. cget -bg]
    $SadieVar(button,point) configure -bg [. cget -bg]
    $SadieVar(button,line) configure -bg [. cget -bg]
    $SadieVar(button,poly) configure -bg [. cget -bg]

    $SadieVar(button,rectangle) configure -activebackground gray
    $SadieVar(button,point) configure -activebackground gray
    $SadieVar(button,line) configure -activebackground gray
    $SadieVar(button,poly) configure -activebackground gray
      
    set SadieVar(tools,shape) $shape

    switch -- $shape {
	rectangle {
	    $SadieVar(button,rectangle) configure -relief sunken
	    $SadieVar(button,rectangle) configure -bg green
	    $SadieVar(button,rectangle) configure -activebackground green
	}
	point {
	    $SadieVar(button,point) configure -relief sunken
	    $SadieVar(button,point) configure -bg green
	    $SadieVar(button,point) configure -activebackground green
	}
	line {
	    $SadieVar(button,line) configure -relief sunken
	    $SadieVar(button,line) configure -bg green
	    $SadieVar(button,line) configure -activebackground green
	}
	poly {
	    $SadieVar(button,poly) configure -relief sunken
	    $SadieVar(button,poly) configure -bg green
	    $SadieVar(button,poly) configure -activebackground green
	}
    }
    
}

#
# register_canvas_info --
#
#       Register an information message for a canvas object.
#
# Arguments:
#       none
#
# Results:
#       Create bindings to display an information message in
#       the tclSadie information window whenever the mouse
#       is over a canvas object.
#
proc register_canvas_info { canvas object statusmesg } {
   $canvas bind $object <Enter> [subst {
      global SadieVar    
      set SadieVar(label,info) "$statusmesg"
   }] 
   $canvas bind $object <Leave> [subst {
      global SadieVar    
      set SadieVar(label,info) ""
   }] 
}

#
# register_window_info --
#
#       Register an information message for a window/widget.
#
# Arguments:
#       none
#
# Results:
#       Create bindings to display an information message in
#       the tclSadie information window whenever the mouse
#       is over a window or widget.
#
proc register_window_info { win statusmesg } {
   bind $win <Enter> [subst {
      global SadieVar    
      set SadieVar(label,info) "$statusmesg"
   }] 
   bind $win <Leave> [subst {
      global SadieVar    
      set SadieVar(label,info) ""
   }] 
   bind $win <Destroy> [subst {
      global SadieVar    
      set SadieVar(label,info) ""
   }] 
   bind $win <Unmap> [subst {
      global SadieVar    
      set SadieVar(label,info) ""
   }] 
}



#
# update_gui --
#
#       Update tclSadie GUI.
#
# Arguments:
#       none
#
# Results:
#       Update GUI and enable/disable menus and buttons
#       based on the characteristics of the current image.
#
proc update_gui {} {
    global SadieVar
      

    #
    # Update the menus
    #
    if { [llength $SadieVar(imagelist)] == 0 } {

        $SadieVar(menu,file) entryconfigure "Print Image" \
            -state disabled

        $SadieVar(menu,file) entryconfigure "Save Image" \
            -state disabled
        $SadieVar(menu,file) entryconfigure "Rename Image" \
            -state disabled
        $SadieVar(menu,file) entryconfigure "Close Current Image" \
            -state disabled
        $SadieVar(menu,file) entryconfigure "Close All Images" \
            -state disabled
            	        
    $SadieVar(button,contrast) configure \
	    -state disabled
	$SadieVar(button,filter) configure \
	    -state disabled
	$SadieVar(button,geometry) configure \
	    -state disabled
	$SadieVar(button,multi) configure \
	    -state disabled
	$SadieVar(button,classify) configure \
	    -state disabled
	$SadieVar(button,tools) configure \
	    -state disabled
            
    $SadieVar(button,statistics) configure \
        -state disabled

    set SadieVar(label,currentimg) "None"
    set SadieVar(label,zoom) ""
    set SadieVar(getstretched) "true"
	set SadieVar(showregions) 0
	$SadieVar(button,regions) configure -state disabled
	set SadieVar(showctrlpts) 1
	$SadieVar(button,ctrlpts) configure -state normal

    } else {

        set currentimg [lindex $SadieVar(imagelist) 0]
        upvar #0 $currentimg imgarray

        $SadieVar(menu,file) entryconfigure "Print Image" \
            -state normal

        $SadieVar(menu,file) entryconfigure "Save Image" \
            -state normal
	    $SadieVar(menu,file) entryconfigure "Rename Image" \
	        -state normal            
        $SadieVar(menu,file) entryconfigure "Close Current Image" \
            -state normal
        $SadieVar(menu,file) entryconfigure "Close All Images" \
            -state normal

	    $SadieVar(button,contrast) configure \
	        -state normal
	    $SadieVar(button,filter) configure \
	        -state normal
	    $SadieVar(button,geometry) configure \
	        -state normal
	    $SadieVar(button,multi) configure \
	        -state normal
	    $SadieVar(button,classify) configure \
	        -state normal
	    $SadieVar(button,tools) configure \
	        -state normal
            
        $SadieVar(button,statistics) configure \
            -state normal
            
        set SadieVar(label,currentimg) $imgarray(title)
        set SadieVar(label,zoom) "$imgarray(zoom)X"
        set SadieVar(getstretched) $imgarray(scaling)
	    set SadieVar(showregions) $imgarray(showregions)
	    set SadieVar(showctrlpts) $imgarray(showctrlpts)
    
        if { [llength $SadieVar(imagelist)] > 1 } {
            $SadieVar(menu,contrast) entryconfigure "Reference Stretch" \
                -state normal
            $SadieVar(menu,multi) entryconfigure "Combine" \
                -state normal
            $SadieVar(menu,multi) entryconfigure "Compare" \
                -state normal
            $SadieVar(menu,classify) entryconfigure "Signature Map" \
                -state normal
            $SadieVar(menu,tools) entryconfigure "RMS Difference" \
                -state normal
        } else {
            $SadieVar(menu,contrast) entryconfigure "Reference Stretch" \
                -state disabled
            $SadieVar(menu,multi) entryconfigure "Combine" \
                -state disabled
            $SadieVar(menu,multi) entryconfigure "Compare" \
                -state disabled
            $SadieVar(menu,classify) entryconfigure "Signature Map" \
                -state disabled
            $SadieVar(menu,tools) entryconfigure "RMS Difference" \
                -state disabled
        }        

        if {$imgarray(region,count) > 0 } {
            $SadieVar(menu,classify) entryconfigure "LevelSlice" \
                -state normal       
            $SadieVar(menu,classify) entryconfigure "Minimum Distance" \
                -state normal       
            $SadieVar(menu,classify) entryconfigure "Maximum Likelihood" \
                -state normal
	    $SadieVar(button,regions) configure -state normal
        } else {
            $SadieVar(menu,classify) entryconfigure "LevelSlice" \
                -state disabled	        
            $SadieVar(menu,classify) entryconfigure "Minimum Distance" \
                -state disabled
            $SadieVar(menu,classify) entryconfigure "Maximum Likelihood" \
                -state disabled
	    $SadieVar(button,regions) configure -state disabled
        }

	if {$imgarray(ctrlpt,count) > 0 } {
	    $SadieVar(button,ctrlpts) configure -state normal
        } else {
	    $SadieVar(button,ctrlpts) configure -state normal
        }

        if {$imgarray(bands) < 2} {

            $SadieVar(menu,multi) entryconfigure "Principal Components Transform" \
                -state disabled
            $SadieVar(menu,multi) entryconfigure "Principal Components Stretch" \
                -state disabled
            $SadieVar(menu,multi) entryconfigure "RGB -> HSV" \
                -state disabled	        
            $SadieVar(menu,multi) entryconfigure "HSV -> RGB" \
                -state disabled	        
            $SadieVar(menu,multi) entryconfigure "BIL -> BSQ (RGB to 3 Bands)" \
                -state disabled

            if {$imgarray(bands) == 1} {
                $SadieVar(menu,tools) entryconfigure "Contour Map" \
                    -state normal
            } else {
                $SadieVar(menu,tools) entryconfigure "Contour Map" \
                    -state disabled
            }	        

            if {[llength $SadieVar(imagelist)] > 1} {
                $SadieVar(menu,tools) entryconfigure "Scattergram" \
                    -state normal
            } else {
                $SadieVar(menu,tools) entryconfigure "Scattergram" \
                    -state disabled
            }

        } else {
            $SadieVar(menu,multi) entryconfigure "Principal Components Transform" \
                -state normal
            $SadieVar(menu,multi) entryconfigure "Principal Components Stretch" \
                -state normal
            $SadieVar(menu,tools) entryconfigure "Contour Map" \
                -state disabled
            $SadieVar(menu,tools) entryconfigure "Scattergram" \
                -state normal

            if {$imgarray(bands) == 3} {
                $SadieVar(menu,multi) entryconfigure "RGB -> HSV" \
                    -state normal	        
                $SadieVar(menu,multi) entryconfigure "HSV -> RGB" \
                    -state normal	        
                $SadieVar(menu,multi) entryconfigure "BIL -> BSQ (RGB to 3 Bands)" \
                    -state normal	        
            } else {
                $SadieVar(menu,multi) entryconfigure "RGB -> HSV" \
                    -state disabled	        
                $SadieVar(menu,multi) entryconfigure "HSV -> RGB" \
                    -state disabled	        
                $SadieVar(menu,multi) entryconfigure "BIL -> BSQ (RGB to 3 Bands)" \
                    -state disabled	        
            }
        }
    }
}



#
# exit_tclSadie --
#
#       Exit the program.
#
# Arguments:
#       none
#
# Results:
#       Close all windows and images, and exit.
#
proc exit_tclSadie {} {
    if {[confirm_ask "Do you really want to quit tclSadie?"]} {
	exit
    }
}


#
# tclSadie_main_init --
#
#       Initialize the program.
#
# Arguments:
#       none
#
# Results:
#       Sets up global variables, handles any platform issues, and initializes
#       default values for parameters.
#
proc tclSadie_main_init {} {
    global SadieVar env
    lappend auto_path $SadieVar(libdir)

    global tcl_platform
    if {$tcl_platform(platform) == "windows"} {
	lappend auto_path d:\\tclSadie_proto_work\\library\\gdi
	lappend auto_path d:\\tclSadie_proto_work\\library\\printing
	Library_UpdateIndex $SadieVar(libdir)

	proc puts {args} {
	    global SadieVar
	    set SadieVar(message) "tcl_output>>> $args\n"
	}

	package require printer
	package require gdi
    }

    #If not an expert user, email bug reports
    #if {![info exists env(TCLSADIE_EXPERT)]} {
    #	email_bug_reports tclSadie-bugs@ece.arizona.edu
    #}

    set SadieVar(fullcolor) 1
    set SadieVar(counter) 0
    set SadieVar(imagelist) {}
    set SadieVar(tools,draw) 0
    set SadieVar(color,regions) "green"
    set SadieVar(color,ctrlpts) "red"
    set SadieVar(sessionlog,pos) 5
    create_main_gui
    create_sessionlog_gui
    Sadie_General_InitializeProg
    set_default_parameters
}

proc tclSadie_proto_init {} {
    tclSadie_main_init
    tclSadie_proto_register
}

#
# set_default_parameters --
#
#       Initialize the parameters for all of the dialogs.
#
# Arguments:
#       none
#
# Results:
#       Calls the initialization procedures for each menu, initializing
#       default values for parameters for dialogs.
#
proc set_default_parameters {} {
    tclSadie_newmenu_init
    tclSadie_multimenu_init
    tclSadie_maintools_init
    tclSadie_contrastmenu_init
    tclSadie_geometrymenu_init
    tclSadie_filtermenu_init
    tclSadie_classifymenu_init
    tclSadie_toolsmenu_init
    tclSadie_fileIO_init
    tclSadie_printing_init
}






