#
# tclSadie_maintools_init --
#
#       Initialize the parameters for the all of the main tclSadie
#       window tool dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_maintools_init {} {
    defineregion_init
    defineprofile_init
    definectrlpt_init
    statistics_init
}



#
# defineregion_dialog --
#
#       Create a dialog box for defining a new region in a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc defineregion_dialog { } {
    global DefineregionVar
    global confirmStatus

    #
    # Determine the current image
    #
    set DefineregionVar(inimg,array) [get_current_image]
    if {$DefineregionVar(inimg,array) != "none"} {
	upvar #0 $DefineregionVar(inimg,array) imgarray
	set DefineregionVar(inimg,name) $imgarray(title)
	set DefineregionVar(inimg,addr) $imgarray(sadie_addr)
	set DefineregionVar(maxbins) [expr [Sadie_General_Gmax $imgarray(sadie_addr)] - \
		[Sadie_General_Gmin $imgarray(sadie_addr)]]
	set DefineregionVar(numbins) $DefineregionVar(maxbins)
	set DefineregionVar(outname) "Region #[expr $imgarray(region,count) + 1]"

	set coords [get_shape_coordinates]
	set DefineregionVar(x1) [lindex $coords 0]
	set DefineregionVar(y1) [lindex $coords 1]
	set DefineregionVar(x2) [lindex $coords 2]
	set DefineregionVar(y2) [lindex $coords 3]
    } else {
	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .defineregiondlg]
    wm geometry $top +110+110
    wm title $top "Define Region Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Define New Region for: "
    label $title.imglbl -fg blue -text $DefineregionVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.incrlbl -text "Subsample Increment: "
    entry $input.incrent -width 5 -textvariable DefineregionVar(incr)
    label $input.incrunits -text "Pixel(s)"

    set DefineregionVar(histentry) $input.histent
    checkbutton $input.histbtn -text "Histogram     Resolution: " -variable DefineregionVar(histogram) \
	    -onvalue 1 -offvalue 0 -command {
	
	global DefineregionVar

	if {$DefineregionVar(histogram)} {
	    $DefineregionVar(histentry) configure -state normal
	    set DefineregionVar(numbins) $DefineregionVar(maxnumbins)
	} else {
	    set DefinereginVar(numbins) ""
	    $DefineregionVar(histentry) configure -state disabled
	}

    }
    entry $DefineregionVar(histentry) -width 5 -textvariable DefineregionVar(numbins)
    label $input.histunits -text "Bin(s)"

    checkbutton $input.matrixbtn -text "Covariance/Correlation Matrix" -variable DefineregionVar(matrix) \
	    -onvalue 1 -offvalue 0
    
    grid $input.incrlbl -row 0 -column 0 -sticky w
    grid $input.incrent -row 0 -column 1 -sticky w
    grid $input.incrunits -row 0 -column 2 -sticky w
    
    grid $input.histbtn -row 1 -column 0 -sticky w
    grid $input.histent -row 1 -column 1 -sticky w
    grid $input.histunits -row 1 -column 2 -sticky w

    grid $input.matrixbtn -row 2 -column 0 -columnspan 3 -sticky w
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Region Name: "
    entry $output.outnameent -width 20 -textvariable DefineregionVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        defineregion_run    
    }


    destroy $top
}
#
# defineregion_run --
#
#       Define a new region based on the parameters from the
#       defineregion dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc defineregion_run {} {
    global DefineregionVar SadieVar
    
    Sadie_Plot_CreateROI $DefineregionVar(inimg,addr) $DefineregionVar(incr) \
	    $DefineregionVar(numbins) $DefineregionVar(matrix) \
	    $DefineregionVar(x1) $DefineregionVar(y1) \
	    $DefineregionVar(x2) $DefineregionVar(y2) $DefineregionVar(outname)

    create_new_region $DefineregionVar(inimg,array) $DefineregionVar(x1) $DefineregionVar(y1) \
	    $DefineregionVar(x2) $DefineregionVar(y2) $DefineregionVar(outname)
}
#
# defineregion_init --
#
#       Initialize the parameters for the defineregion dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc defineregion_init {} {
    global DefineregionVar
    
    set DefineregionVar(inimg,array) "none"
    set DefineregionVar(inimg,name) "none"
    set DefineregionVar(inimg,addr) "none"
    set DefineregionVar(maxbins) 0
    set DefineregionVar(incr) 1
    set DefineregionVar(histogram) 1
    set DefineregionVar(numbins) 0
    set DefineregionVar(matrix) 1
    set DefineregionVar(outname) "Region #1"
}




#
# defineprofile_dialog --
#
#       Create a dialog box for defining a new profile in a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc defineprofile_dialog { } {
    global DefineprofileVar
    global confirmStatus

    #
    # Determine the current image
    #
    set DefineprofileVar(inimg,array) [get_current_image]
    if {$DefineprofileVar(inimg,array) != "none"} {
	upvar #0 $DefineprofileVar(inimg,array) imgarray
	set DefineprofileVar(inimg,name) $imgarray(title)
	set DefineprofileVar(inimg,addr) $imgarray(sadie_addr)

	set coords [get_shape_coordinates]
	set DefineprofileVar(x1) [lindex $coords 0]
	set DefineprofileVar(y1) [lindex $coords 1]
	set DefineprofileVar(x2) [lindex $coords 2]
	set DefineprofileVar(y2) [lindex $coords 3]
    } else {
	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .defineprofiledlg]
    wm geometry $top +110+110
    wm title $top "Profile Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Create A Profile for: "
    label $title.imglbl -fg blue -text $DefineprofileVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.label -text "Scale: "
    radiobutton $input.linear  -text "Linear" -variable DefineprofileVar(option) -value 1
    radiobutton $input.log  -text "Logarithmic" -variable DefineprofileVar(option) -value 2
    radiobutton $input.unit  -text "\[-1,+1\]" -variable DefineprofileVar(option) -value 0
    
    grid $input.label -row 0 -column 0 -sticky w
    grid $input.linear -row 0 -column 1 -sticky w
    grid $input.log -row 1 -column 1 -sticky w
    grid $input.unit -row 2 -column 1 -sticky w

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        defineprofile_run    
    }


    destroy $top
}
#
# defineprofile_run --
#
#       Define a new profile based on the parameters from the
#       defineprofile dialog.
#
# Arguments:
#       None
#
# Results:
#       The new profile is created.
#
proc defineprofile_run {} {
    global DefineprofileVar
    
    Sadie_Plot_Profile $DefineprofileVar(inimg,addr) $DefineprofileVar(x1) $DefineprofileVar(y1) \
	    $DefineprofileVar(x2) $DefineprofileVar(y2) $DefineprofileVar(option)
}
#
# defineprofile_init --
#
#       Initialize the parameters for the defineprofile dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc defineprofile_init {} {
    global DefineprofileVar
    
    set DefineprofileVar(inimg,array) "none"
    set DefineprofileVar(inimg,name) "none"
    set DefineprofileVar(inimg,addr) "none"
    set DefineprofileVar(option) 1
}







#
# definectrlpt_dialog --
#
#       Create a dialog box for defining a new control point in a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc definectrlpt_dialog { } {
    global DefinectrlptVar
    global confirmStatus

    #
    # Determine the current image
    #
    set DefinectrlptVar(inimg,array) [get_current_image]
    if {$DefinectrlptVar(inimg,array) != "none"} {
	upvar #0 $DefinectrlptVar(inimg,array) imgarray
	set DefinectrlptVar(inimg,name) $imgarray(title)
	set DefinectrlptVar(inimg,addr) $imgarray(sadie_addr)
	set DefinectrlptVar(outname) "Ctrlpt #[expr $imgarray(ctrlpt,count) + 1]"

	set coords [get_shape_coordinates]
	set DefinectrlptVar(x1) [lindex $coords 0]
	set DefinectrlptVar(y1) [lindex $coords 1]
    } else {
	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .defctrlptdlg]
    wm geometry $top +110+110
    wm title $top "Define Control Point Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Define New Control Point for: "
    label $title.imglbl -fg blue -text $DefinectrlptVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.coordlbl -text "Control Point Coordinates: "
    label $input.coordpt  -text "       ( [expr $DefinectrlptVar(x1)+1] , [expr $DefinectrlptVar(y1)+1] )       "

    grid $input.coordlbl -row 0 -column 0 -sticky w
    grid $input.coordpt -row 1 -column 0 -sticky w
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Control Point Name: "
    entry $output.outnameent -width 20 -textvariable DefinectrlptVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        definectrlpt_run    
    }


    destroy $top
}
#
# definectrlpt_run --
#
#       Define a new ctrlpt based on the parameters from the
#       definectrlpt dialog.
#
# Arguments:
#       None
#
# Results:
#       The new ctrlpt is created.
#
proc definectrlpt_run {} {
    global DefinectrlptVar SadieVar
    
    create_new_ctrlpt $DefinectrlptVar(inimg,array) $DefinectrlptVar(x1) $DefinectrlptVar(y1) \
	    $DefinectrlptVar(outname)
}
#
# definectrlpt_init --
#
#       Initialize the parameters for the definectrlpt dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc definectrlpt_init {} {
    global DefinectrlptVar
    
    set DefinectrlptVar(inimg,array) "none"
    set DefinectrlptVar(inimg,name) "none"
    set DefinectrlptVar(inimg,addr) "none"
    set DefinectrlptVar(outname) "Point #1"
}





#
# statistics_dialog --
#
#       Create a dialog box for computing statistics for a displayed
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc statistics_dialog { } {
    global StatisticsVar
    global confirmStatus

    #
    # Determine the current image
    #
    set StatisticsVar(inimg,array) [get_current_image]
    if {$StatisticsVar(inimg,array) != "none"} {
	upvar #0 $StatisticsVar(inimg,array) imgarray
	set StatisticsVar(inimg,name) $imgarray(title)
	set StatisticsVar(inimg,addr) $imgarray(sadie_addr)
	set StatisticsVar(range,min) [Sadie_General_Gmin $imgarray(sadie_addr)]
	set StatisticsVar(range,max) [Sadie_General_Gmax $imgarray(sadie_addr)]
	set StatisticsVar(maxbins) [expr [Sadie_General_Gmax $imgarray(sadie_addr)] - \
		[Sadie_General_Gmin $imgarray(sadie_addr)]]
	set StatisticsVar(numbins) [expr round($StatisticsVar(maxbins))]
	set StatisticsVar(range,use) 0
    } else {
	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .statisticsdlg]
    wm geometry $top +110+110
    wm title $top "Statistics Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Compute Statistics for: "
    label $title.imglbl -fg blue -text $StatisticsVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.incrlbl -text "Subsample Increment: "
    entry $input.incrent -width 5 -textvariable StatisticsVar(incr)
    label $input.incrunits -text "Pixel(s)"

    set StatisticsVar(histentry) $input.histent
    checkbutton $input.histbtn -text "Histogram     Resolution: " -variable StatisticsVar(histogram) \
	    -onvalue 1 -offvalue 0 -command {
	
	global StatisticsVar

	if {$StatisticsVar(histogram)} {
	    $StatisticsVar(histentry) configure -state normal
	    set StatisticsVar(numbins) [expr round($StatisticsVar(maxnumbins))]
	} else {
	    set DefinereginVar(numbins) ""
	    $StatisticsVar(histentry) configure -state disabled
	}

    }
    entry $StatisticsVar(histentry) -width 5 -textvariable StatisticsVar(numbins)
    label $input.histunits -text "Bin(s)"

    checkbutton $input.matrixbtn -text "Covariance/Correlation Matrix" -variable StatisticsVar(matrix) \
	    -onvalue 1 -offvalue 0

    set range $input.range
    set StatisticsVar(range,frame) $range
    frame $range
    
    checkbutton $range.rangeusebtn -text "Pixel Graylevel Range Constraints:" -variable StatisticsVar(range,use) \
	    -onvalue 1 -offvalue 0 \
	    -command {
	                 global StatisticsVar
	                 set range $StatisticsVar(range,frame)
	
	                 if {$StatisticsVar(range,use) == 1} {
			     $range.rangetype1 configure -state normal
			     $range.rangetype2 configure -state normal
			     $range.rangemin configure -state normal -fg [$range.fromlbl cget -fg]
			     $range.rangemax configure -state normal -fg [$range.fromlbl cget -fg]			     
	                 } else {
			     $range.rangetype1 configure -state disabled
			     $range.rangetype2 configure -state disabled
			     $range.rangemin configure -state disabled -fg [$range.rangemin cget -bg]
			     $range.rangemax configure -state disabled -fg [$range.rangemax cget -bg]			     
			 }
                      }

    radiobutton $range.rangetype1 -text "include: " -variable StatisticsVar(range,type) -value 1 -state disabled
    radiobutton $range.rangetype2 -text "exclude: " -variable StatisticsVar(range,type) -value 2 -state disabled

    label $range.fromlbl -text "   from "
    label $range.fromunits -text " graylevel"
    entry $range.rangemin -width 5 -textvariable StatisticsVar(range,min) -state disabled -fg [$input.incrent cget -bg]

    label $range.tolbl   -text "     to "
    label $range.tounits -text " graylevel"
    entry $range.rangemax -width 5 -textvariable StatisticsVar(range,max) -state disabled -fg [$input.incrent cget -bg]

    grid $range.rangeusebtn -row 0 -column 0 -columnspan 6 -sticky w
    grid $range.rangetype1 -row 1 -column 1 -sticky w
    grid $range.fromlbl -row 1 -column 2 -sticky w
    grid $range.rangemin -row 1 -column 3 -sticky w
    grid $range.fromunits -row 1 -column 4 -sticky w
    grid $range.rangetype2 -row 2 -column 1 -sticky w
    grid $range.tolbl -row 2 -column 2 -sticky w
    grid $range.rangemax -row 2 -column 3 -sticky w
    grid $range.tounits -row 2 -column 4 -sticky w
    grid columnconfigure $range 0 -minsize 20
    grid columnconfigure $range 5 -weight 1

		      
    grid $input.incrlbl -row 0 -column 0 -sticky w
    grid $input.incrent -row 0 -column 1 -sticky w
    grid $input.incrunits -row 0 -column 2 -sticky w
    
    grid $input.histbtn -row 1 -column 0 -sticky w
    grid $input.histent -row 1 -column 1 -sticky w
    grid $input.histunits -row 1 -column 2 -sticky w

    grid $input.matrixbtn -row 2 -column 0 -columnspan 3 -sticky w

    grid $input.range -row 4 -column 0 -columnspan 4 -sticky w
    grid rowconfigure $input 3 -minsize 20

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        statistics_run    
    }


    destroy $top
}
#
# statistics_run --
#
#       Define a new region based on the parameters from the
#       statistics dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc statistics_run {} {
    global StatisticsVar
    
    Sadie_Plot_Statistics $StatisticsVar(inimg,addr) $StatisticsVar(incr) \
	    $StatisticsVar(numbins) $StatisticsVar(matrix) \
	    [expr $StatisticsVar(range,use) * $StatisticsVar(range,type)] \
	    $StatisticsVar(range,min) $StatisticsVar(range,max)
}
#
# statistics_init --
#
#       Initialize the parameters for the statistics dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc statistics_init {} {
    global StatisticsVar
    
    set StatisticsVar(inimg,array) "none"
    set StatisticsVar(inimg,name) "none"
    set StatisticsVar(inimg,addr) "none"
    set StatisticsVar(maxbins) 0
    set StatisticsVar(incr) 1
    set StatisticsVar(histogram) 1
    set StatisticsVar(numbins) 0
    set StatisticsVar(matrix) 1
    set StatisticsVar(range,use) 0
    set StatisticsVar(range,type) 1
    set StatisticsVar(range,min) 0.0
    set StatisticsVar(range,max) 0.0
}
