#
# tclSadie_multimenu_init --
#
#       Initialize the parameters for the all of the multi menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_multimenu_init {} {
    combine_init
    compare_init
    pct_init
    pcs_init
    rgb2hsv_init
    hsv2rgb_init
    bil2bsq_init
    bsq2bil_init
    complex2real_init
    real2complex_init
    rotatecube_init
}



#
# combine_dialog --
#
#       Create a dialog box for combining two images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc combine_dialog { } {
    global CombineVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .combinedlg]
    wm geometry $top +110+110
    wm title $top "Combine Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Combine Two Images"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    entry $input.mult1ent -width 5 -textvariable CombineVar(weight1)
    label $input.mult1lbl -text "*"
    create_image_selector $input.image1 "CombineVar" "inimg,addr1" 0

    tk_optionMenu $input.option CombineVar(type) \
        "+" "-" "*" "/" "min" "max"
    entry $input.mult2ent -width 5 -textvariable CombineVar(weight2)
    label $input.mult2lbl -text "*"
    create_image_selector $input.image2 "CombineVar" "inimg,addr2" 1
    
    grid $input.mult1ent -row 0 -column 1 -sticky ew
    grid $input.mult1lbl -row 0 -column 2 -padx 5 -sticky ew
    grid $input.image1 -row 0 -column 3 -sticky ew
    
    grid $input.option -row 1 -column 0 -padx 5 -sticky ew
    grid $input.mult2ent -row 1 -column 1 -sticky ew
    grid $input.mult2lbl -row 1 -column 2 -padx 5 -sticky ew
    grid $input.image2 -row 1 -column 3 -sticky ew
    
    grid columnconfigure $input 0 -minsize 80
    grid columnconfigure $input 3 -minsize 150
    grid columnconfigure $input 3 -weight 1
        

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable CombineVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        combine_run    
    }


    destroy $top
}
#
# combine_run --
#
#       Create a combined image based on the parameters from the
#       combine dialog.
#
# Arguments:
#       None
#
# Results:
#       The combined image is created and displayed.
#
proc combine_run {} {
    global CombineVar

    set CombineVar(option) $CombineVar($CombineVar(type),option)
    
    set out_sadie_addr [Sadie_Multi_Combine CombineVar]
    
    create_display_image $CombineVar(outname) $out_sadie_addr
}
#
# combine_init --
#
#       Initialize the parameters for the combine dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc combine_init {} {
    global CombineVar
    
    set CombineVar(weight1) 1.0
    set CombineVar(weight2) 1.0
    set CombineVar(inimg,addr1) ""
    set CombineVar(inimg,addr2) ""
    set CombineVar(type) "+"
    set CombineVar(+,option) 0
    set CombineVar(-,option) 1
    set CombineVar(*,option) 2
    set CombineVar(/,option) 3
    set CombineVar(min,option) 4
    set CombineVar(max,option) 5
    set CombineVar(outname) "Combine"
}



#
# compare_dialog --
#
#       Create a dialog box for comparing two images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc compare_dialog { } {
    global CompareVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .comparedlg]
    wm geometry $top +110+110
    wm title $top "Compare Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Compare Two Images"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    create_image_selector $input.image1 "CompareVar" "inimg,addr1" 0

    tk_optionMenu $input.option CompareVar(type) \
        "<" "<=" ">" ">=" "=" "!=" "and" "or" "xor" "not"
    create_image_selector $input.image2 "CompareVar" "inimg,addr2" 1
    
    grid $input.image1 -row 0 -column 1 -sticky ew
    
    grid $input.option -row 1 -column 0 -padx 5 -sticky ew
    grid $input.image2 -row 1 -column 1 -sticky ew
    
    grid columnconfigure $input 0 -minsize 80
    grid columnconfigure $input 1 -minsize 150
    grid columnconfigure $input 1 -weight 1
        

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable CompareVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        compare_run    
    }


    destroy $top
}
#
# compare_run --
#
#       Create a compared image based on the parameters from the
#       compare dialog.
#
# Arguments:
#       None
#
# Results:
#       The compared image is created and displayed.
#
proc compare_run {} {
    global CompareVar

    set CompareVar(option) $CompareVar($CompareVar(type),option)
    
    set out_sadie_addr [Sadie_Multi_Compare CompareVar]
    
    create_display_image $CompareVar(outname) $out_sadie_addr
}
#
# compare_init --
#
#       Initialize the parameters for the compare dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc compare_init {} {
    global CompareVar
    
    set CompareVar(inimg,addr1) ""
    set CompareVar(inimg,addr2) ""
    set CompareVar(type) "<"
    set CompareVar(<,option) 0
    set CompareVar(<=,option) 1
    set CompareVar(>,option) 2
    set CompareVar(>=,option) 3
    set CompareVar(=,option) 4
    set CompareVar(!=,option) 5
    set CompareVar(and,option) 6
    set CompareVar(or,option) 7
    set CompareVar(xor,option) 8
    set CompareVar(not,option) 9
    set CompareVar(outname) "Compare"
}



#
# pct_dialog --
#
#       Create a dialog box for performing a principal components transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc pct_dialog { } {
    global PCTVar
    global confirmStatus

    #
    # Determine the current image
    #
    set PCTVar(inimg,array) [get_current_image]
    if {$PCTVar(inimg,array) != "none"} {
	    upvar #0 $PCTVar(inimg,array) imgarray
	    set PCTVar(inimg,name) $imgarray(title)
	    set PCTVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .pctdlg]
    wm geometry $top +110+110
    wm title $top "PCT Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Principal Components Transform on:"
    label $title.imglbl -fg blue -text $PCTVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Subsample Increment: "}
    lappend row {entry PCTVar(incr)}
    lappend row {label "Pixel(s) and Line(s)"}
    dialog_create_stdrow $input 0 $row
        

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable PCTVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        pct_run    
    }


    destroy $top
}
#
# pct_run --
#
#       Create a pctd image based on the parameters from the
#       pct dialog.
#
# Arguments:
#       None
#
# Results:
#       The pctd image is created and displayed.
#
proc pct_run {} {
    global PCTVar

    set out_sadie_addr [Sadie_Multi_PCT PCTVar]
    
    create_display_image $PCTVar(outname) $out_sadie_addr
}
#
# pct_init --
#
#       Initialize the parameters for the pct dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc pct_init {} {
    global PCTVar
    
    set PCTVar(inimg,array) "none"
    set PCTVar(inimg,name) "none"
    set PCTVar(inimg,addr) "none"
    set PCTVar(incr) 1
    set PCTVar(outname) "PCT"
}



#
# pcs_dialog --
#
#       Create a dialog box for performing a principal components stretch
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc pcs_dialog { } {
    global PCSVar
    global confirmStatus

    #
    # Determine the current image
    #
    set PCSVar(inimg,array) [get_current_image]
    if {$PCSVar(inimg,array) != "none"} {
	    upvar #0 $PCSVar(inimg,array) imgarray
	    set PCSVar(inimg,name) $imgarray(title)
	    set PCSVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .pcsdlg]
    wm geometry $top +110+110
    wm title $top "PCS Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Principal Components Stretch on:"
    label $title.imglbl -fg blue -text $PCSVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Subsample Increment: "}
    lappend row {entry PCSVar(incr)}
    lappend row {label "Pixel(s) and Line(s)"}
    dialog_create_stdrow $input 0 $row
        

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable PCSVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        pcs_run    
    }


    destroy $top
}
#
# pcs_run --
#
#       Create a pcsd image based on the parameters from the
#       pcs dialog.
#
# Arguments:
#       None
#
# Results:
#       The pcsd image is created and displayed.
#
proc pcs_run {} {
    global PCSVar

    set out_sadie_addr [Sadie_Multi_PCS PCSVar]
    
    create_display_image $PCSVar(outname) $out_sadie_addr
}
#
# pcs_init --
#
#       Initialize the parameters for the pcs dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc pcs_init {} {
    global PCSVar
    
    set PCSVar(inimg,array) "none"
    set PCSVar(inimg,name) "none"
    set PCSVar(inimg,addr) "none"
    set PCSVar(incr) 1
    set PCSVar(outname) "PCS"
}



#
# rgb2hsv_dialog --
#
#       Create a dialog box for performing a RGB to HSV transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc rgb2hsv_dialog { } {
    global RGB2HSVVar
    global confirmStatus

    #
    # Determine the current image
    #
    set RGB2HSVVar(inimg,array) [get_current_image]
    if {$RGB2HSVVar(inimg,array) != "none"} {
	    upvar #0 $RGB2HSVVar(inimg,array) imgarray
	    set RGB2HSVVar(inimg,name) $imgarray(title)
	    set RGB2HSVVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .rgb2hsvdlg]
    wm geometry $top +110+110
    wm title $top "RGB to HSV Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform RBG to HSV transform on:"
    label $title.imglbl -fg blue -text $RGB2HSVVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RGB2HSVVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        rgb2hsv_run    
    }


    destroy $top
}
#
# rgb2hsv_run --
#
#       Create a rgb2hsvd image based on the parameters from the
#       rgb2hsv dialog.
#
# Arguments:
#       None
#
# Results:
#       The rgb2hsvd image is created and displayed.
#
proc rgb2hsv_run {} {
    global RGB2HSVVar

    set out_sadie_addr [Sadie_Multi_RGB2HSV RGB2HSVVar]
    
    create_display_image $RGB2HSVVar(outname) $out_sadie_addr
}
#
# rgb2hsv_init --
#
#       Initialize the parameters for the rgb2hsv dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc rgb2hsv_init {} {
    global RGB2HSVVar
    
    set RGB2HSVVar(inimg,array) "none"
    set RGB2HSVVar(inimg,name) "none"
    set RGB2HSVVar(inimg,addr) "none"
    set RGB2HSVVar(outname) "RGB2HSV"
}



#
# hsv2rgb_dialog --
#
#       Create a dialog box for performing a HSV to RGB transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc hsv2rgb_dialog { } {
    global HSV2RGBVar
    global confirmStatus

    #
    # Determine the current image
    #
    set HSV2RGBVar(inimg,array) [get_current_image]
    if {$HSV2RGBVar(inimg,array) != "none"} {
	    upvar #0 $HSV2RGBVar(inimg,array) imgarray
	    set HSV2RGBVar(inimg,name) $imgarray(title)
	    set HSV2RGBVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .hsv2rgbdlg]
    wm geometry $top +110+110
    wm title $top "HSV to RGB Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform HSV to RBG transform on:"
    label $title.imglbl -fg blue -text $HSV2RGBVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable HSV2RGBVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        hsv2rgb_run    
    }


    destroy $top
}
#
# hsv2rgb_run --
#
#       Create a HSV2RGBd image based on the parameters from the
#       HSV2RGB dialog.
#
# Arguments:
#       None
#
# Results:
#       The HSV2RGBd image is created and displayed.
#
proc hsv2rgb_run {} {
    global HSV2RGBVar

    set out_sadie_addr [Sadie_Multi_HSV2RGB HSV2RGBVar]
    
    create_display_image $HSV2RGBVar(outname) $out_sadie_addr
}
#
# hsv2rgb_init --
#
#       Initialize the parameters for the HSV2RGB dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc hsv2rgb_init {} {
    global HSV2RGBVar
    
    set HSV2RGBVar(inimg,array) "none"
    set HSV2RGBVar(inimg,name) "none"
    set HSV2RGBVar(inimg,addr) "none"
    set HSV2RGBVar(outname) "HSV2RGB"
}



#
# bil2bsq_dialog --
#
#       Create a dialog box for performing a BIL to BSQ transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc bil2bsq_dialog { } {
    global BIL2BSQVar
    global confirmStatus

    #
    # Determine the current image
    #
    set BIL2BSQVar(inimg,array) [get_current_image]
    if {$BIL2BSQVar(inimg,array) != "none"} {
	    upvar #0 $BIL2BSQVar(inimg,array) imgarray
	    set BIL2BSQVar(inimg,name) $imgarray(title)
	    set BIL2BSQVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .bil2bsqdlg]
    wm geometry $top +110+110
    wm title $top "BIL to BSQ Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform BIL to BSQ transform on:"
    label $title.imglbl -fg blue -text $BIL2BSQVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Names: "
    entry $output.outnameent1 -width 20 -textvariable BIL2BSQVar(outname1)
    entry $output.outnameent2 -width 20 -textvariable BIL2BSQVar(outname2)
    entry $output.outnameent3 -width 20 -textvariable BIL2BSQVar(outname3)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent1 -row 0 -column 1 -sticky ew
    grid $output.outnameent2 -row 1 -column 1 -sticky ew
    grid $output.outnameent3 -row 2 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        bil2bsq_run    
    }


    destroy $top
}
#
# bil2bsq_run --
#
#       Create a bil2bsqd image based on the parameters from the
#       bil2bsq dialog.
#
# Arguments:
#       None
#
# Results:
#       The bil2bsqd image is created and displayed.
#
proc bil2bsq_run {} {
    global BIL2BSQVar

    set results [Sadie_Multi_BIL2BSQ BIL2BSQVar]

    set out_sadie_addr1 [lindex $results 0]
    create_display_image $BIL2BSQVar(outname1) $out_sadie_addr1

    set out_sadie_addr2 [lindex $results 1]
    create_display_image $BIL2BSQVar(outname2) $out_sadie_addr2

    set out_sadie_addr3 [lindex $results 2]
    create_display_image $BIL2BSQVar(outname3) $out_sadie_addr3
}
#
# bil2bsq_init --
#
#       Initialize the parameters for the bil2bsq dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc bil2bsq_init {} {
    global BIL2BSQVar
    
    set BIL2BSQVar(inimg,array) "none"
    set BIL2BSQVar(inimg,name) "none"
    set BIL2BSQVar(inimg,addr) "none"
    set BIL2BSQVar(outname1) "Red"
    set BIL2BSQVar(outname2) "Green"
    set BIL2BSQVar(outname3) "Blue"
}



#
# bsq2bil_dialog --
#
#       Create a dialog box for performing a BSQ to BIL transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc bsq2bil_dialog { } {
    global BSQ2BILVar
    global confirmStatus

    #
    # Determine the current image
    #
    set BSQ2BILVar(inimg,array) [get_current_image]
    if {$BSQ2BILVar(inimg,array) != "none"} {
	    upvar #0 $BSQ2BILVar(inimg,array) imgarray
	    set BSQ2BILVar(inimg,name) $imgarray(title)
	    set BSQ2BILVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .bsq2bildlg]
    wm geometry $top +110+110
    wm title $top "BSQ to BIL Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform BSQ to BIL transform on:"
    label $title.imglbl -fg blue -text $BSQ2BILVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    set row {}
    lappend row {label "Red Image: "}
    lappend row {imgchooser BSQ2BILVar(inimg,addr1) 0}
    dialog_create_stdrow $input 0 $row
    
    set row {}
    lappend row {label "Green Image: "}
    lappend row {imgchooser BSQ2BILVar(inimg,addr2) 1}
    dialog_create_stdrow $input 1 $row
    
    set row {}
    lappend row {label "Blue Image: "}
    lappend row {imgchooser BSQ2BILVar(inimg,addr3) 2}
    dialog_create_stdrow $input 2 $row
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable BSQ2BILVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        bsq2bil_run    
    }


    destroy $top
}
#
# bsq2bil_run --
#
#       Create a bsq2bild image based on the parameters from the
#       bsq2bil dialog.
#
# Arguments:
#       None
#
# Results:
#       The bsq2bild image is created and displayed.
#
proc bsq2bil_run {} {
    global BSQ2BILVar

    set out_sadie_addr [Sadie_Multi_BSQ2BIL BSQ2BILVar]
    
    create_display_image $BSQ2BILVar(outname) $out_sadie_addr
}
#
# bsq2bil_init --
#
#       Initialize the parameters for the bsq2bil dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc bsq2bil_init {} {
    global BSQ2BILVar
    
    set BSQ2BILVar(inimg,addr1) ""
    set BSQ2BILVar(inimg,addr2) ""
    set BSQ2BILVar(inimg,addr3) ""
    set BSQ2BILVar(outname) "BSQ2BIL"
}




#
# complex2real_dialog --
#
#       Create a dialog box for performing a complex to real transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc complex2real_dialog { } {
    global COMPLEX2REALVar
    global confirmStatus

    #
    # Determine the current image
    #
    set COMPLEX2REALVar(inimg,array) [get_current_image]
    if {$COMPLEX2REALVar(inimg,array) != "none"} {
	    upvar #0 $COMPLEX2REALVar(inimg,array) imgarray
	    set COMPLEX2REALVar(inimg,name) $imgarray(title)
	    set COMPLEX2REALVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .complex2realdlg]
    wm geometry $top +110+110
    wm title $top "Complex to Real Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Complex to Real transform on:"
    label $title.imglbl -fg blue -text $COMPLEX2REALVar(inimg,name)
    grid $title.titlelbl -sticky news
    grid $title.imglbl -sticky new

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {radiobutton "Real/Imaginary"  COMPLEX2REALVar(option) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {radiobutton "Magnitude/Phase"  COMPLEX2REALVar(option) 1}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Names: "
    entry $output.outnameent1 -width 20 -textvariable COMPLEX2REALVar(outname1)
    entry $output.outnameent2 -width 20 -textvariable COMPLEX2REALVar(outname2)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent1 -row 0 -column 1 -sticky ew
    grid $output.outnameent2 -row 1 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        complex2real_run    
    }


    destroy $top
}
#
# complex2real_run --
#
#       Create a complex2reald image based on the parameters from the
#       complex2real dialog.
#
# Arguments:
#       None
#
# Results:
#       The complex2reald image is created and displayed.
#
proc complex2real_run {} {
    global COMPLEX2REALVar

    set results [Sadie_Multi_Comp2Real COMPLEX2REALVar]

    set out_sadie_addr1 [lindex $results 0]
    create_display_image $COMPLEX2REALVar(outname1) $out_sadie_addr1

    set out_sadie_addr2 [lindex $results 1]
    create_display_image $COMPLEX2REALVar(outname2) $out_sadie_addr2
}
#
# complex2real_init --
#
#       Initialize the parameters for the complex2real dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc complex2real_init {} {
    global COMPLEX2REALVar
    
    set COMPLEX2REALVar(inimg,array) "none"
    set COMPLEX2REALVar(inimg,name) "none"
    set COMPLEX2REALVar(inimg,addr) "none"
    set COMPLEX2REALVar(option) 0
    set COMPLEX2REALVar(outname1) "Real"
    set COMPLEX2REALVar(outname2) "Imag"
}



#
# real2complex_dialog --
#
#       Create a dialog box for performing a real to complex transform
#       on an input image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc real2complex_dialog { } {
    global REAL2COMPLEXVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .real2complexdlg]
    wm geometry $top +110+110
    wm title $top "Real to Complex Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Real to Complex transform"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {radiobutton "Real/Imaginary"  REAL2COMPLEXVar(option) 0}
    lappend row {imgchooser REAL2COMPLEXVar(inimg,addr1) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {radiobutton "Magnitude/Phase"  REAL2COMPLEXVar(option) 1}
    lappend row {imgchooser REAL2COMPLEXVar(inimg,addr2) 1}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Names: "
    entry $output.outnameent -width 20 -textvariable REAL2COMPLEXVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        real2complex_run    
    }


    destroy $top
}
#
# real2complex_run --
#
#       Create a real2complexd image based on the parameters from the
#       real2complex dialog.
#
# Arguments:
#       None
#
# Results:
#       The real2complexd image is created and displayed.
#
proc real2complex_run {} {
    global REAL2COMPLEXVar

    set out_sadie_addr [Sadie_Multi_Real2Comp REAL2COMPLEXVar]

    create_display_image $REAL2COMPLEXVar(outname) $out_sadie_addr
}
#
# real2complex_init --
#
#       Initialize the parameters for the real2complex dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc real2complex_init {} {
    global REAL2COMPLEXVar
    
    set REAL2COMPLEXVar(inimg,addr1) ""
    set REAL2COMPLEXVar(inimg,addr2) ""
    set REAL2COMPLEXVar(option) 0
    set REAL2COMPLEXVar(outname) "Complex"
}




#
# rotatecube_dialog --
#
#       Create a dialog box for rotating a Hypercube
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc rotatecube_dialog { } {
    global RotatecubeVar
    global confirmStatus

    #
    # Determine the current image
    #
    set RotatecubeVar(inimg,array) [get_current_image]
    if {$RotatecubeVar(inimg,array) != "none"} {
	    upvar #0 $RotatecubeVar(inimg,array) imgarray
	    set RotatecubeVar(inimg,name) $imgarray(title)
	    set RotatecubeVar(inimg,addr) $imgarray(sadie_addr)
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .rotatecubedlg]
    wm geometry $top +110+110
    wm title $top "Rotate Image Cube"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Image Cube Rotation on: "
    label $title.imglbl -fg blue -bg white -relief sunken -text $RotatecubeVar(inimg,name)
    grid $title.titlelbl x $title.imglbl -sticky news -ipadx 2

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    label $input.maplbl -text "Specify Mapping: "

    # Create Frames
    frame $input.outfrm -borderwidth 2 -relief ridge
    frame $input.outfrm.c1r1 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c1r2 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c1r3 -borderwidth 2 -relief sunken     
    frame $input.outfrm.c1r4 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c2r1 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c2r2 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c2r3 -borderwidth 2 -relief sunken  
    frame $input.outfrm.c2r4 -borderwidth 2 -relief sunken       
    frame $input.outfrm.c3r1 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c3r2 -borderwidth 2 -relief sunken
    frame $input.outfrm.c3r3 -borderwidth 2 -relief sunken 
    frame $input.outfrm.c3r4 -borderwidth 2 -relief sunken   
        
    # Create titles
    label $input.outfrm.c1r1.maplbl -text "Map\n Axis" -fg blue 
    label $input.outfrm.c2r1.inlbl -text "In\n Order" -fg blue  
    label $input.outfrm.c3r1.tolbl -text "To\n Axis" -fg blue 

    # Axis labels - column 1
    label $input.outfrm.c1r2.xlbl -text "X" 
    label $input.outfrm.c1r3.ylbl -text "Y"  
    label $input.outfrm.c1r4.zlbl -text "Z" 
    
    # Order Buttons and labels - column 2
    radiobutton $input.outfrm.c2r2.xbtnplus  -text Normal -variable RotatecubeVar(x,sign) \
	-value 0 
    radiobutton $input.outfrm.c2r2.xbtnminus -text Flip -variable RotatecubeVar(x,sign) \
	-value 1 
    radiobutton $input.outfrm.c2r3.ybtnplus  -text Normal -variable RotatecubeVar(y,sign) \
	-value 0 
    radiobutton $input.outfrm.c2r3.ybtnminus -text Flip -variable RotatecubeVar(y,sign) \
	-value 1 
    radiobutton $input.outfrm.c2r4.zbtnplus  -text Normal -variable RotatecubeVar(z,sign) \
	-value 0 
    radiobutton $input.outfrm.c2r4.zbtnminus -text Flip -variable RotatecubeVar(z,sign) \
	-value 1 

    # To Axis Menu Buttons - column 3
    set RotatecubeVar(x,sign) 0
    set RotatecubeVar(y,sign) 0
    set RotatecubeVar(z,sign) 0

    tk_optionMenu $input.outfrm.c3r2.cubedimx RotatecubeVar(x,cubedim) \
	 Pixel Line Band
    tk_optionMenu $input.outfrm.c3r3.cubedimy RotatecubeVar(y,cubedim) \
	 Pixel Line Band
    tk_optionMenu $input.outfrm.c3r4.cubedimz RotatecubeVar(z,cubedim) \
	 Pixel Line Band
    $input.outfrm.c3r2.cubedimx configure -width 6
    $input.outfrm.c3r3.cubedimy configure -width 6
    $input.outfrm.c3r4.cubedimz configure -width 6 

    set RotatecubeVar(x,cubedim) Pixel
    set RotatecubeVar(y,cubedim) Line
    set RotatecubeVar(z,cubedim) Band
    set RotatecubeVar(x,oldcubedim) $RotatecubeVar(x,cubedim)
    set RotatecubeVar(y,oldcubedim) $RotatecubeVar(y,cubedim)
    set RotatecubeVar(z,oldcubedim) $RotatecubeVar(z,cubedim)
    trace variable RotatecubeVar w rotatecube_change
    
    # Place widgets using grid geometry manager
    grid $input.maplbl -row 0 -column 0 -sticky w

    # Button frame and sub-frames 
    grid $input.outfrm -row 2 -column 0 -rowspan 4 -columnspan 3 -padx 20
    grid $input.outfrm.c1r1 -row 0 -column 0 -sticky news
    grid $input.outfrm.c1r2 -row 1 -column 0 -sticky news
    grid $input.outfrm.c1r3 -row 2 -column 0 -sticky news
    grid $input.outfrm.c1r4 -row 3 -column 0 -sticky news   
    grid $input.outfrm.c2r1 -row 0 -column 1 -sticky news
    grid $input.outfrm.c2r2 -row 1 -column 1 -sticky news
    grid $input.outfrm.c2r3 -row 2 -column 1 -sticky news
    grid $input.outfrm.c2r4 -row 3 -column 1 -sticky news
    grid $input.outfrm.c3r1 -row 0 -column 2 -sticky news
    grid $input.outfrm.c3r2 -row 1 -column 2 -sticky news
    grid $input.outfrm.c3r3 -row 2 -column 2 -sticky news
    grid $input.outfrm.c3r4 -row 3 -column 2 -sticky news

    # Column 1
    grid $input.outfrm.c1r1.maplbl -row 0 -column 0 -sticky n
    grid $input.outfrm.c1r2.xlbl   -row 0 -column 0 -sticky nw
    grid $input.outfrm.c1r3.ylbl   -row 0 -column 0 -sticky nw
    grid $input.outfrm.c1r4.zlbl   -row 0 -column 0 -sticky nw

    # Column 2
    grid $input.outfrm.c2r1.inlbl     -row 0 -column 0 -columnspan 2 -sticky n
    grid $input.outfrm.c2r2.xbtnplus  -row 0 -column 0 -sticky nw
    grid $input.outfrm.c2r2.xbtnminus -row 0 -column 1 -sticky nw
    grid $input.outfrm.c2r3.ybtnplus  -row 0 -column 0 -sticky nw
    grid $input.outfrm.c2r3.ybtnminus -row 0 -column 1 -sticky nw
    grid $input.outfrm.c2r4.zbtnplus  -row 0 -column 0 -sticky nw
    grid $input.outfrm.c2r4.zbtnminus -row 0 -column 1 -sticky nw

    # Column 3
    grid $input.outfrm.c3r1.tolbl    -row 0 -column 0 -sticky n    
    grid $input.outfrm.c3r2.cubedimx -row 0 -column 0 -sticky nw -padx 5 -pady 2
    grid $input.outfrm.c3r3.cubedimy -row 0 -column 0 -sticky nw -padx 5 -pady 2
    grid $input.outfrm.c3r4.cubedimz -row 0 -column 0 -sticky nw -padx 5 -pady 2

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RotatecubeVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        rotatecube_run    
    }


    destroy $top
}

proc rotatecube_change { varName index op } {
    global RotatecubeVar

    switch $index {
	x,cubedim {
	    if { $RotatecubeVar(y,cubedim) == $RotatecubeVar(x,cubedim) } {
		set RotatecubeVar(y,cubedim) $RotatecubeVar(x,oldcubedim)
	    } elseif { $RotatecubeVar(z,cubedim) == $RotatecubeVar(x,cubedim) } {
		set RotatecubeVar(z,cubedim) $RotatecubeVar(x,oldcubedim)
	    }
	}
	y,cubedim {
	    if { $RotatecubeVar(x,cubedim) == $RotatecubeVar(y,cubedim) } {
		set RotatecubeVar(x,cubedim) $RotatecubeVar(y,oldcubedim)
	    } elseif { $RotatecubeVar(z,cubedim) == $RotatecubeVar(y,cubedim) } {
		set RotatecubeVar(z,cubedim) $RotatecubeVar(y,oldcubedim)
	    }
	}
	z,cubedim {
	    if { $RotatecubeVar(x,cubedim) == $RotatecubeVar(z,cubedim) } {
		set RotatecubeVar(x,cubedim) $RotatecubeVar(z,oldcubedim)
	    } elseif { $RotatecubeVar(y,cubedim) == $RotatecubeVar(z,cubedim) } {
		set RotatecubeVar(y,cubedim) $RotatecubeVar(z,oldcubedim)
	    }
	}
    }
    set RotatecubeVar(x,oldcubedim) $RotatecubeVar(x,cubedim)
    set RotatecubeVar(y,oldcubedim) $RotatecubeVar(y,cubedim)
    set RotatecubeVar(z,oldcubedim) $RotatecubeVar(z,cubedim)    
}

#
# rotatecube_run --
#
#       Rotate Hypercube based on the parameters from the
#       rotatecube dialog.
#
# Arguments:
#       None
#
# Results:
#       The rotated image-cube is displayed.
#


proc rotatecube_run {} {
    global RotatecubeVar
    
    switch $RotatecubeVar(x,cubedim) {
	Pixel {
	    set RotatecubeVar(x,cubedim) 2
	}
	Line {
	    set RotatecubeVar(x,cubedim) 1
	}
	Band {
	    set RotatecubeVar(x,cubedim) 0
	}
    }
    switch $RotatecubeVar(y,cubedim) {
	Pixel {
	    set RotatecubeVar(y,cubedim) 2
	}
	Line {
	    set RotatecubeVar(y,cubedim) 1
	}
	Band {
	    set RotatecubeVar(y,cubedim) 0
	}
    }
    switch $RotatecubeVar(z,cubedim) {
	Pixel {
	    set RotatecubeVar(z,cubedim) 2
	}
	Line {
	    set RotatecubeVar(z,cubedim) 1
	}
	Band {
	    set RotatecubeVar(z,cubedim) 0
	}
    }
    
    set out_sadie_addr [Sadie_Multi_RotateCube RotatecubeVar]

    create_display_image $RotatecubeVar(outname) $out_sadie_addr 
}

#
# rotatecube_init --
#
#       Initialize the parameters for the rotatecube dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
    
proc rotatecube_init {} {
    global RotatecubeVar
    
    set RotatecubeVar(inimg,array) "none"
    set RotatecubeVar(inimg,name) "none"
    set RotatecubeVar(inimg,addr) "none"
    set RotatecubeVar(outname) "RotCube"
}
