#
# tclSadie_newmenu_init --
#
#       Initialize the parameters for the all of the new menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_newmenu_init {} {
    sinewave_init
    chirp_init
    checkerboard_init
    uniform_init
    gray_scale_init
    random_init
    sinestar_init
    function_init
}



#
# sinewave_dialog --
#
#       Create a dialog box for generating a sine wave image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc sinewave_dialog { } {
    global SineWaveVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .sinewvdlg]
    wm geometry $top +110+110
    wm title $top "Sine Wave Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Sine Wave Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry SineWaveVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry SineWaveVar(pix)}
    lappend row {label "Pixels(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Period: "}
    lappend row {entry SineWaveVar(period)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Phase: "}
    lappend row {entry SineWaveVar(phase)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 2 $row
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SineWaveVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        sinewave_run    
    }


    destroy $top
}
#
# sinewave_run --
#
#       Create a sine wave image based on the parameters from the
#       sine wave dialog.
#
# Arguments:
#       None
#
# Results:
#       The sine wave image is created and displayed.
#
proc sinewave_run {} {
    global SineWaveVar
    
    set out_sadie_addr [Sadie_NewFunctions_SineWave SineWaveVar]
    
    create_display_image $SineWaveVar(outname) $out_sadie_addr
}
#
# sinewave_init --
#
#       Initialize the parameters for the sine wave dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc sinewave_init {} {
    global SineWaveVar
    
    set SineWaveVar(lines) 64
    set SineWaveVar(pix) 64
    set SineWaveVar(period) 32.0
    set SineWaveVar(phase) 0.0
    set SineWaveVar(outname) "Sine"
}



#
# checkerboard_dialog --
#
#       Create a dialog box for generating a checker board image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc checkerboard_dialog { } {
    global CheckerVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .chkrbddlg]
    wm geometry $top +110+110
    wm title $top "Checker Board Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Checker Board Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    label $input.sizelbl -text "Image Size: "
    entry $input.linesent -width 5 -textvariable CheckerVar(lines)
    label $input.linesunits -text "Line(s)     "
    entry $input.pixent -width 5 -textvariable CheckerVar(pix)
    label $input.pixunits -text "Pixel(s)"

    label $input.checksizelbl -text "Check Size: "
    entry $input.checklinesent -width 5 -textvariable CheckerVar(checklines)
    label $input.checklinesunits -text "Line(s)     "
    entry $input.checkpixent -width 5 -textvariable CheckerVar(checkpix)
    label $input.checkpixunits -text "Pixel(s)"
    
    grid $input.sizelbl -row 1 -column 0 -sticky nws
    grid $input.linesent -row 1 -column 1 -sticky nws
    grid $input.linesunits -row 1 -column 2 -sticky nws
    grid $input.pixent -row 1 -column 3 -sticky nws
    grid $input.pixunits -row 1 -column 4 -sticky nws

    grid $input.checksizelbl -row 2 -column 0 -sticky nws
    grid $input.checklinesent -row 2 -column 1 -sticky nws
    grid $input.checklinesunits -row 2 -column 2 -sticky nws
    grid $input.checkpixent -row 2 -column 3 -sticky nws
    grid $input.checkpixunits -row 2 -column 4 -sticky nws


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable CheckerVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        checkerboard_run    
    }


    destroy $top
}
#
# checkerboard_run --
#
#       Create a checker board image based on the parameters from the
#       checker board dialog.
#
# Arguments:
#       None
#
# Results:
#       The checker board image is created and displayed.
#
proc checkerboard_run {} {
    global CheckerVar
    
    set out_sadie_addr [Sadie_NewFunctions_Checkerboard CheckerVar]
    
    create_display_image $CheckerVar(outname) $out_sadie_addr
}
#
# checkerboard_init --
#
#       Initialize the parameters for the checker board dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc checkerboard_init {} {
    global CheckerVar
    
    set CheckerVar(lines) 64
    set CheckerVar(pix) 64
    set CheckerVar(checklines) 8
    set CheckerVar(checkpix) 8
    set CheckerVar(outname) "Checker"
}



#
# chirp_dialog --
#
#       Create a dialog box for generating a chirp image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc chirp_dialog { } {
    global ChirpVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .chirpdlg]
    wm geometry $top +110+110
    wm title $top "Chirp Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Chirp Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    label $input.sizelbl -text "Image Size: "
    entry $input.linesent -width 5 -textvariable ChirpVar(lines)
    label $input.linesunits -text "Line(s)     "
    entry $input.pixent -width 5 -textvariable ChirpVar(pix)
    label $input.pixunits -text "Pixel(s)"

    label $input.periodlbl -text "Period: "
    entry $input.periodent -width 5 -textvariable ChirpVar(period)
    label $input.periodunits -text "Pixel(s)"
    
    grid $input.sizelbl -row 1 -column 0 -sticky nws
    grid $input.linesent -row 1 -column 1 -sticky nws
    grid $input.linesunits -row 1 -column 2 -sticky nws
    grid $input.pixent -row 1 -column 3 -sticky nws
    grid $input.pixunits -row 1 -column 4 -sticky nws

    grid $input.periodlbl -row 2 -column 0 -sticky nws
    grid $input.periodent -row 2 -column 1 -sticky nws
    grid $input.periodunits -row 2 -column 2 -sticky nws
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ChirpVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        chirp_run    
    }


    destroy $top
}
#
# chirp_run --
#
#       Create a chirp image based on the parameters from the
#       chirp dialog.
#
# Arguments:
#       None
#
# Results:
#       The sine wave image is created and displayed.
#
proc chirp_run {} {
    global ChirpVar
    
    set out_sadie_addr [Sadie_NewFunctions_Chirp ChirpVar]

    create_display_image $ChirpVar(outname) $out_sadie_addr
}
#
# chirp_init --
#
#       Initialize the parameters for the chirp dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc chirp_init {} {
    global ChirpVar
    
    set ChirpVar(lines) 64
    set ChirpVar(pix) 64
    set ChirpVar(period) 64.0
    set ChirpVar(outname) "Chirp"
}




#
# uniform_dialog --
#
#       Create a dialog box for generating a uniform image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc uniform_dialog { } {
    global UniformVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .uniformdlg]
    wm geometry $top +110+110
    wm title $top "Uniform Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Uniform Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry UniformVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry UniformVar(pix)}
    lappend row {label "Pixels(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Graylevel: "}
    lappend row {entry UniformVar(level)}
    dialog_create_stdrow $input 1 $row



    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable UniformVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        uniform_run    
    }


    destroy $top
}
#
# uniform_run --
#
#       Create a uniform image based on the parameters from the
#       uniform dialog.
#
# Arguments:
#       None
#
# Results:
#       The uniform image is created and displayed.
#
proc uniform_run {} {
    global UniformVar
    
    set UniformVar(min) $UniformVar(level)
    set UniformVar(max) $UniformVar(level)
    
    
    set out_sadie_addr [Sadie_NewFunctions_GrayScale UniformVar]
    
    create_display_image $UniformVar(outname) $out_sadie_addr
}
#
# uniform_init --
#
#       Initialize the parameters for the uniform dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc uniform_init {} {
    global UniformVar
    
    set UniformVar(lines) 64
    set UniformVar(pix) 64
    set UniformVar(level) 0.0
    set UniformVar(number) 1
    set UniformVar(outname) "Uniform"
}




#
# gray_scale_dialog --
#
#       Create a dialog box for generating a gray scale image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc gray_scale_dialog { } {
    global GrayscaleVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .grayscldlg]
    wm geometry $top +110+110
    wm title $top "Gray Scale Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Gray Scale Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry GrayscaleVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry GrayscaleVar(pix)}
    lappend row {label "Pixels(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Graylevels: "}
    lappend row {entry GrayscaleVar(min)}
    lappend row {label "Minimum"}
    lappend row {entry GrayscaleVar(max)}
    lappend row {label "Maximum"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {skip}
    lappend row {entry GrayscaleVar(number)}
    lappend row {label "Number"}
    dialog_create_stdrow $input 2 $row


    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable GrayscaleVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        gray_scale_run    
    }


    destroy $top
}
#
# gray_scale_run --
#
#       Create a gray scale image based on the parameters from the
#       gray scale dialog.
#
# Arguments:
#       None
#
# Results:
#       The gray scale image is created and displayed.
#
proc gray_scale_run {} {
    global GrayscaleVar
    
    set out_sadie_addr [Sadie_NewFunctions_GrayScale GrayscaleVar]
    
    create_display_image $GrayscaleVar(outname) $out_sadie_addr
}
#
# gray_scale_init --
#
#       Initialize the parameters for the gray scale dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc gray_scale_init {} {
    global GrayscaleVar
    
    set GrayscaleVar(lines) 64
    set GrayscaleVar(pix) 64
    set GrayscaleVar(min) 0.0
    set GrayscaleVar(max) 255.0
    set GrayscaleVar(number) 64
    set GrayscaleVar(outname) "Gray"
}


#
# random_dialog --
#
#       Create a dialog box for generating a random image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc random_dialog { } {
    global RandomVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .randomdlg]
    wm geometry $top +110+110
    wm title $top "Random Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a Random Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry RandomVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry RandomVar(pix)}
    lappend row {label "Pixels(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Distribution: "}
    lappend row {chooser RandomVar(dist) {"Uniform" "Gaussian"} 3}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Deviation"}
    lappend row {entry RandomVar(deviation)}
    dialog_create_stdrow $input 2 $row
    


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable RandomVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        random_run    
    }


    destroy $top
}
#
# random_run --
#
#       Create a random image based on the parameters from the
#       random dialog.
#
# Arguments:
#       None
#
# Results:
#       The random image is created and displayed.
#
proc random_run {} {
    global RandomVar

    switch $RandomVar(dist) {
       "Uniform" {set RandomVar(type) 0}
        default  {set RandomVar(type) 1}
    }
    
    set out_sadie_addr [Sadie_NewFunctions_Random RandomVar]
    
    create_display_image $RandomVar(outname) $out_sadie_addr
}
#
# random_init --
#
#       Initialize the parameters for the random dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc random_init {} {
    global RandomVar
    
    set RandomVar(lines) 64
    set RandomVar(pix) 64
    set RandomVar(dist) "Uniform"
    set RandomVar(deviation) 5.0
    set RandomVar(outname) "Random"
}


#
# sinestar_dialog --
#
#       Create a dialog box for generating a sinestar image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc sinestar_dialog { } {
    global SinestarVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .sinstrdlg]
    wm geometry $top +110+110
    wm title $top "Sine Star Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Sine Star Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry SinestarVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry SinestarVar(pix)}
    lappend row {label "Pixels(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Period: "}
    lappend row {entry SinestarVar(period)}
    dialog_create_stdrow $input 1 $row

    


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable SinestarVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        sinestar_run    
    }


    destroy $top
}
#
# sinestar_run --
#
#       Create a sine star image based on the parameters from the
#       sine star dialog.
#
# Arguments:
#       None
#
# Results:
#       The gray scale image is created and displayed.
#
proc sinestar_run {} {
    global SinestarVar
    
    set out_sadie_addr [Sadie_NewFunctions_SineStar SinestarVar]
    
    create_display_image $SinestarVar(outname) $out_sadie_addr
}
#
# sinestar_init --
#
#       Initialize the parameters for the sine star dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc sinestar_init {} {
    global SinestarVar
    
    set SinestarVar(lines) 64
    set SinestarVar(pix) 64
    set SinestarVar(period) 1.0
    set SinestarVar(outname) "SineStar"
}


#
# function_dialog --
#
#       Create a dialog box for generating a function image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc function_dialog { } {
    global FunctionVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .functiondlg]
    wm geometry $top +110+110
    wm title $top "Function Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Generate a New Function Image"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Image Size: "}
    lappend row {entry FunctionVar(lines)}
    lappend row {label "Line(s)"}
    lappend row {entry FunctionVar(pix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Function Radius: "}
    lappend row {entry FunctionVar(radiuslines)}
    lappend row {label "Line(s)"}
    lappend row {entry FunctionVar(radiuspix)}
    lappend row {label "Pixel(s)"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Function Type"}
    lappend row {chooser FunctionVar(functype) {"Cone" "Negative Exponential" "Gaussian" "Box" "Cylinder" "Hanning" "Hamming" "Kaiser"}}
    lappend row {label "Alpha for Kaiser"}
    lappend row {entry FunctionVar(alpha)}
    dialog_create_stdrow $input 2 $row


    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable FunctionVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        function_run    
    }


    destroy $top
}
#
# function_run --
#
#       Create a function image based on the parameters from the
#       function dialog.
#
# Arguments:
#       None
#
# Results:
#       The function image is created and displayed.
#
proc function_run {} {
    global FunctionVar

    switch $FunctionVar(functype) {
       "Cone"                 {set FunctionVar(type) 0}
       "Negative Exponential" {set FunctionVar(type) 1}
       "Gaussian"             {set FunctionVar(type) 2}
       "Box"                  {set FunctionVar(type) 3}
       "Cylinder"             {set FunctionVar(type) 4}
       "Hanning"              {set FunctionVar(type) 5}
       "Hamming"              {set FunctionVar(type) 6}
       "Kaiser"               {set FunctionVar(type) 7}
       default                {set FunctionVar(type) 8}
    }
    
    set out_sadie_addr [Sadie_NewFunctions_Function FunctionVar]
    
    create_display_image $FunctionVar(outname) $out_sadie_addr
}
#
# function_init --
#
#       Initialize the parameters for the function dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc function_init {} {
    global FunctionVar
    
    set FunctionVar(lines) 64
    set FunctionVar(pix) 64
    set FunctionVar(radiuslines) 32.0
    set FunctionVar(radiuspix) 32.0
    set FunctionVar(type) "Cone"
    set FunctionVar(outname) "Function"
    set FunctionVar(alpha) 3.0
}


