#
# tclSadie_toolsmenu_init --
#
#       Initialize the parameters for the all of the tools menu dialogs.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters
#       for each dialog.
#
proc tclSadie_toolsmenu_init {} {
    destripe_init
    contmap_init
    relief_init
    scattergram_init
    rmsdiff_init
}





#
# destripe_dialog --
#
#       Create a dialog box for performing destripe on a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc destripe_dialog { } {
    global DestripeVar
    global confirmStatus

    #
    # Determine the current image
    #
    set DestripeVar(inimg,array) [get_current_image]
    if {$DestripeVar(inimg,array) != "none"} {
	    upvar #0 $DestripeVar(inimg,array) imgarray
	    set DestripeVar(inimg,name) $imgarray(title)
	    set DestripeVar(inimg,addr) $imgarray(sadie_addr)
	    set DestripeVar(defaultbins) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .destripedlg]
    wm geometry $top +110+110
    wm title $top "Destripe Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Perform Destripe on: "
    label $title.imglbl -fg blue -text $DestripeVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]

    label $input.methodlbl -text "Method: "
    tk_optionMenu $input.methodtype DestripeVar(type) "Mean" "Mean & Standard Deviation" "Cumulative Distribution"
    entry $input.numberent -width 5 -textvariable DestripeVar(number)
    label $input.binslbl -text "Bins"

    label $input.periodlbl -text "Striping Period: "
    entry $input.periodent -width 5 -textvariable DestripeVar(period)
    label $input.periodunits -text "Line(s)"

    label $input.reflbl -text "Reference: "
    radiobutton $input.detectnum -text "Detector Number: " -variable DestripeVar(reference) -value 0 \
	    -command {destripe_update "" "" ""}
    radiobutton $input.detectavg -text "Detector Average" -variable DestripeVar(reference) -value 1 \
	    -command {destripe_update "" "" ""}
    entry $input.detectorent -width 5 -textvariable DestripeVar(detector)

    set DestripeVar(entry,fg) [$input.detectorent cget -fg]
    set DestripeVar(entry,bg) [$input.detectorent cget -bg]

    grid $input.methodlbl -row 0 -column 0 -sticky w -pady 2
    grid $input.methodtype -row 0 -column 1 -columnspan 4 -sticky w -pady 2
    grid $input.numberent -row 0 -column 5 -sticky ew -pady 2
    grid $input.binslbl -row 0 -column 6 -sticky ew -pady 2
    grid columnconfigure $input 4 -minsize 20

    grid $input.periodlbl -row 1 -column 0 -sticky w -pady 2
    grid $input.periodent -row 1 -column 1 -sticky w -pady 2
    grid $input.periodunits -row 1 -column 2 -sticky w -pady 2
    
    grid $input.reflbl -row 2 -column 0 -sticky w -pady 2
    grid $input.detectnum -row 2 -column 1 -columnspan 2 -sticky w -pady 2
    grid $input.detectorent -row 2 -column 3 -sticky w -pady 2
    grid $input.detectavg -row 3 -column 1 -columnspan 2 -sticky w -pady 2

    grid columnconfigure $input 4 -minsize 30

    trace variable DestripeVar(type) w destripe_update
    destripe_update "" "" ""

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable DestripeVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        destripe_run    
    }


    destroy $top
}
proc destripe_update {varName index op} {
    global DestripeVar

    set input [dialog_input .destripedlg]

    if {$DestripeVar(type) == "Mean"} {
	set DestripeVar(option) 0
	set DestripeVar(number) 0
	$input.numberent configure -state disabled -fg $DestripeVar(entry,bg)
    } elseif {$DestripeVar(type) == "Mean & Standard Deviation"} {
	set DestripeVar(option) 1
	set DestripeVar(number) 0
	$input.numberent configure -state disabled -fg $DestripeVar(entry,bg)
    } else {
	set DestripeVar(option) 2
	set DestripeVar(number) $DestripeVar(defaultbins)
	$input.numberent configure -state normal -fg $DestripeVar(entry,fg)
    }

    if {$DestripeVar(reference)} {
	$input.detectorent configure -state disabled -fg $DestripeVar(entry,bg)
	set DestripeVar(detector) 0
    } else {
	$input.detectorent configure -state normal -fg $DestripeVar(entry,fg)
	set DestripeVar(detector) 1
    }
}
#
# destripe_run --
#
#       Define a new region based on the parameters from the
#       destripe dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc destripe_run {} {
    global DestripeVar
    
    set out_sadie_addr [Sadie_Tools_Destripe DestripeVar]

    create_display_image $DestripeVar(outname) $out_sadie_addr
}
#
# destripe_init --
#
#       Initialize the parameters for the destripe dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc destripe_init {} {
    global DestripeVar
    
    set DestripeVar(inimg,array) "none"
    set DestripeVar(inimg,name) "none"
    set DestripeVar(inimg,addr) "none"
    set DestripeVar(option) 0
    set DestripeVar(type) "Mean"
    set DestripeVar(reference) 0
    set DestripeVar(period) 1
    set DestripeVar(detector) 0
    set DestripeVar(number) 0
    set DestripeVar(outname) "Destripe"
}



#
# contmap_dialog --
#
#       Create a dialog box for producing a contour map of a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc contmap_dialog { } {
    global ContmapVar
    global confirmStatus

    #
    # Determine the current image
    #
    set ContmapVar(inimg,array) [get_current_image]
    if {$ContmapVar(inimg,array) != "none"} {
	    upvar #0 $ContmapVar(inimg,array) imgarray
	    set ContmapVar(inimg,name) $imgarray(title)
	    set ContmapVar(inimg,addr) $imgarray(sadie_addr)
	    set ContmapVar(defaultbins) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .contmapdlg]
    wm geometry $top +110+110
    wm title $top "Contour Map Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Create Contour Map from: "
    label $title.imglbl -fg blue -text $ContmapVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Contour Lines: "}
    lappend row {entry ContmapVar(number)}
    lappend row {label "Number"}
    dialog_create_stdrow $input 0 $row
    
    set row {}
    lappend row {skip}
    lappend row {entry ContmapVar(width)}
    lappend row {label "Width"}
    dialog_create_stdrow $input 1 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ContmapVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        contmap_run    
    }


    destroy $top
}
#
# contmap_run --
#
#       Define a new region based on the parameters from the
#       contmap dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc contmap_run {} {
    global ContmapVar
    
    set out_sadie_addr [Sadie_Tools_ContMap ContmapVar]

    create_display_image $ContmapVar(outname) $out_sadie_addr
}
#
# contmap_init --
#
#       Initialize the parameters for the contour map dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc contmap_init {} {
    global ContmapVar
    
    set ContmapVar(number) 8
    set ContmapVar(width) 0.1
    set ContmapVar(outname) "Contour Map"
}



#
# relief_dialog --
#
#       Create a dialog box for producing a shaded relief of a display
#       image.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc relief_dialog { } {
    global ReliefVar
    global confirmStatus

    #
    # Determine the current image
    #
    set ReliefVar(inimg,array) [get_current_image]
    if {$ReliefVar(inimg,array) != "none"} {
	    upvar #0 $ReliefVar(inimg,array) imgarray
	    set ReliefVar(inimg,name) $imgarray(title)
	    set ReliefVar(inimg,addr) $imgarray(sadie_addr)
	    set ReliefVar(defaultbins) [expr round([Sadie_General_Gmax $imgarray(sadie_addr)] - [Sadie_General_Gmin $imgarray(sadie_addr)]) + 1]
    } else {
    	return
    }
    
    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .reliefdlg]
    wm geometry $top +110+110
    wm title $top "Shaded Relief Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Create Shaded Relief from: "
    label $title.imglbl -fg blue -text $ReliefVar(inimg,name)
    grid $title.titlelbl $title.imglbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "Horizontal Illumination Angle: "}
    lappend row {entry ReliefVar(phi)}
    lappend row {label "degrees"}
    dialog_create_stdrow $input 0 $row
    
    set row {}
    lappend row {label "Vertical Illumination Angle: "}
    lappend row {entry ReliefVar(theta)}
    lappend row {label "degrees"}
    dialog_create_stdrow $input 1 $row

    set row {}
    lappend row {label "Pixel Distance: "}
    lappend row {entry ReliefVar(dist)}
    lappend row {label "(Units of Z)"}
    dialog_create_stdrow $input 2 $row

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ReliefVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        relief_run    
    }


    destroy $top
}
#
# relief_run --
#
#       Define a new region based on the parameters from the
#       shaded relief dialog.
#
# Arguments:
#       None
#
# Results:
#       The new region is created.
#
proc relief_run {} {
    global ReliefVar
    
    set out_sadie_addr [Sadie_Tools_Relief ReliefVar]

    create_display_image $ReliefVar(outname) $out_sadie_addr
}
#
# relief_init --
#
#       Initialize the parameters for the shaded relief dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc relief_init {} {
    global ReliefVar
    
    set ReliefVar(phi) 135.0
    set ReliefVar(theta) 45.0
    set ReliefVar(dist) 1.0
    set ReliefVar(outname) "Relief"
}




#
# scattergram_dialog --
#
#       Create a dialog box for computing a scattergram from two bands.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc scattergram_dialog { } {
    global ScatterVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .scatterdlg]
    wm geometry $top +110+110
    wm title $top "Scattergram Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Create a Scattergram from Two Bands"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    label $input.img1lbl -text "First Band: "
    create_image_selector $input.image1 "ScatterVar" "inimg,addr1" 0
    label $input.band1lbl -text "  Band: "
    set ScatterVar(bandmenu1) [tk_optionMenu $input.band1 ScatterVar(band1) 1 2 3]

    label $input.img2lbl -text "Second Band: "
    create_image_selector $input.image2 "ScatterVar" "inimg,addr2" 1
    label $input.band2lbl -text "  Band: "
    set ScatterVar(bandmenu2) [tk_optionMenu $input.band2 ScatterVar(band2) 1 2 3]
    
    label $input.reslbl -text "Histogram Resolution: "
    entry $input.resent -width 5 -textvariable ScatterVar(res)
    label $input.resunits -text "Bins"

    label $input.incrlbl -text "Subsample Increment: "
    entry $input.incrent -width 5 -textvariable ScatterVar(incr)
    label $input.incrunits -text "Pixel(s) and Line(s)"

    grid $input.img1lbl -row 0 -column 0 -sticky w
    grid $input.image1 -row 0 -column 1 -columnspan 3 -sticky w
    grid $input.band1lbl -row 0 -column 4 -sticky w
    grid $input.band1 -row 0 -column 5 -sticky w

    grid $input.img2lbl -row 1 -column 0 -sticky w
    grid $input.image2 -row 1 -column 1 -columnspan 3 -sticky w
    grid $input.band2lbl -row 1 -column 4 -sticky w
    grid $input.band2 -row 1 -column 5 -sticky w
    
    grid $input.reslbl -row 2 -column 0 -sticky w
    grid $input.resent -row 2 -column 1 -sticky w
    grid $input.resunits -row 2 -column 2 -sticky w

    grid $input.incrlbl -row 3 -column 0 -sticky w
    grid $input.incrent -row 3 -column 1 -sticky w
    grid $input.incrunits -row 3 -column 2 -columnspan 4 -sticky w

    grid columnconfigure $input 2 -minsize 100 -weight 1

    trace variable ScatterVar(inimg,addr1) w scattergram_update
    trace variable ScatterVar(inimg,addr2) w scattergram_update

    scattergram_update
    
    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    label $output.outnamelbl -text "Image Name: "
    entry $output.outnameent -width 20 -textvariable ScatterVar(outname)

    grid columnconfigure $output 1 -weight 1
    grid $output.outnamelbl -row 0 -column 0 -sticky w
    grid $output.outnameent -row 0 -column 1 -sticky ew
    
    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        scattergram_run    
    }

    trace vdelete ScatterVar(inimg,addr1) w scattergram_update
    trace vdelete ScatterVar(inimg,addr2) w scattergram_update

    destroy $top
}
proc scattergram_update {args} {
    global ScatterVar

    set numbands [Sadie_General_GetNumBands $ScatterVar(inimg,addr1)]
    $ScatterVar(bandmenu1) delete 0 end
    for {set i 1} {$i <= $numbands} {incr i} {
	$ScatterVar(bandmenu1) add command -label $i \
	    -command [subst {
		global ScatterVar
		set ScatterVar(band1) $i
	    }]
    }
    
    set numbands [Sadie_General_GetNumBands $ScatterVar(inimg,addr2)]
    $ScatterVar(bandmenu2) delete 0 end
    for {set i 1} {$i <= $numbands} {incr i} {
	$ScatterVar(bandmenu2) add command -label $i \
	    -command [subst {
		global ScatterVar
		set ScatterVar(band2) $i
	    }]
    }
    
    set ScatterVar(band1) 1
    set ScatterVar(band2) 1
}
#
# scattergram_run --
#
#       Create a scatterd image based on the parameters from the
#       scatter dialog.
#
# Arguments:
#       None
#
# Results:
#       The scatterd image is created and displayed.
#
proc scattergram_run {} {
    global ScatterVar

    set out_sadie_addr [Sadie_Tools_Scatter ScatterVar]
    
    create_display_image $ScatterVar(outname) $out_sadie_addr
}
#
# scattergram_init --
#
#       Initialize the parameters for the scatter dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc scattergram_init {} {
    global ScatterVar
    
    set ScatterVar(inimg,addr1) ""
    set ScatterVar(inimg,addr2) ""
    set ScatterVar(res) "256"
    set ScatterVar(incr) "1"
    set ScatterVar(outname) "Scatter"
}



#
# rmsdiff_dialog --
#
#       Create a dialog box for computing the RMS difference between two images.
#
# Arguments:
#       None
#
# Results:
#       The dialog box is created and grabs input until either
#       OK or CANCEL button is pressed by user.
#
proc rmsdiff_dialog { } {
    global RmsdiffVar
    global confirmStatus

    #
    # Create the dialog 
    #
    set top [dialog_create Dialog .rmsdiffdlg]
    wm geometry $top +110+110
    wm title $top "RMS Difference Dialog"
    wm protocol $top WM_DELETE_WINDOW {dialog_set_confirm 0}
    bind $top <Return> {dialog_set_confirm 1}
    
    #
    # Create the dialog title section
    #
    set title [dialog_title $top]
    label $title.titlelbl -text "Compute RMS Difference of Two Images"
    grid $title.titlelbl -sticky news

    #
    # Create the dialog input section
    #
    set input [dialog_input $top]
    
    set row {}
    lappend row {label "First Image: "}
    lappend row {imgchooser RmsdiffVar(inimg,addr1) 0}
    dialog_create_stdrow $input 0 $row

    set row {}
    lappend row {label "Second Image: "}
    lappend row {imgchooser RmsdiffVar(inimg,addr2) 1}
    dialog_create_stdrow $input 1 $row

    grid columnconfigure $input 1 -minsize 200
    

    #
    # Create the dialog output section
    #
    set output [dialog_output $top]

    
    #
    # Create the dialog controls
    #
    set cntls [dialog_controls $top]
    dialog_buttons $cntls {dialog_set_confirm 1} {dialog_set_confirm 0}
    
    
    #
    # Wait for a response
    #
    dialog_wait $top confirmStatus
    if {$confirmStatus == 1} {
        rmsdiff_run    
    }


    destroy $top
}
#
# rmsdiff_run --
#
#       Create a rmsdiffd image based on the parameters from the
#       rmsdiff dialog.
#
# Arguments:
#       None
#
# Results:
#       The rmsdiffd image is created and displayed.
#
proc rmsdiff_run {} {
    global RmsdiffVar

    set out_sadie_addr [Sadie_Tools_RMS RmsdiffVar]
}
#
# rmsdiff_init --
#
#       Initialize the parameters for the rmsdiff dialog.
#
# Arguments:
#       None
#
# Results:
#       A global variable array is created to store the parameters.
#
proc rmsdiff_init {} {
    global RmsdiffVar
    
    set RmsdiffVar(inimg,addr1) ""
    set RmsdiffVar(inimg,addr2) ""
}
