/** @file Sadie_Index.h
 * A general application data-storage interface for tclSadie.
 * In addition to various global data structures dedicated
 * to specific purposes, tclSadie uses a generalized extensible
 * storage mechanism following a two-level hierarchy, with the
 * top-level entities (documents or images) containing lower
 * level properties.  We hide all the implementation details
 * behind opaque pointers (for example, the sad_doclistp_t
 * pointers), presenting just the interface defined here to
 * the rest of the application.
 *
 * @author University of Arizona Digital Image Analysis Lab
 * @date 1999, 2004
 * @version $Id: Sadie_Index.h,v 1.1 2005/03/22 20:18:37 mmunro Exp $
 */

/* This file is part of tclSadie.

   tclSadie is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   tclSadie is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with tclSadie; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.  */

#ifndef SADIE_INDEX_H
/** The standard guard against including the same header twice. */
#define SADIE_INDEX_H 1
#include "project_utilities.h"

BEGIN_C_DECLARATIONS

/** Prototype for the data destructor callbacks associated with properties. */ 
typedef void (*sad_property_data_destructor_t) (void *);

/** An opaque pointer to the complete top level document (image) list. */
typedef struct Sad_doclist * sad_doclistp_t;

void dispose_doclist (sad_doclistp_t thedoclist);

sad_doclistp_t make_doclist (int logsize);

int sad_dispose_doc (sad_doclistp_t doclist, const char *dkey);

int sad_put_doc (sad_doclistp_t doclist, const char *dkey,
                 int logpsize, const IMAGE *img);

int sad_put_doc_property (sad_doclistp_t doclist, const char *dkey,
                          const char *pkey,
                          sad_property_data_destructor_t destruct,
                          void *data);

void * sad_get_doc_property (const sad_doclistp_t doclist,
                             const char *dkey, const char *pkey);

END_C_DECLARATIONS

#endif /* !SADIE_INDEX_H */
