/** @file bresenham.h
 * A generic Bresenham line algorithm.
 * We can hide the implementaion details of the Bresenham line algorithm
 * behind an interface that only exposes some generic object
 * construction and destruction operations, and an iterator that
 * generates the next set of coordinates.
 *
 * @author University of Arizona Digital Image Analysis Lab
 * @date 1999, 2004
 * @version $Id: bresenham.h,v 1.1 2005/03/22 20:26:18 mmunro Exp $
 */

/* This file is part of tclSadie.

   tclSadie is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   tclSadie is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with tclSadie; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.  */

#ifndef BRESENHAM_H
/** The standard guard against including the same header twice. */
#define BRESENHAM_H 1
#include "project_utilities.h"

BEGIN_C_DECLARATIONS

/** An opaque pointer to the line tracking state. */
typedef struct Bresenham_line * bresenham_linep_t;

bresenham_linep_t bresenham_from_s_coord (int32_t first_col,
                                          int32_t first_row,
                                          int32_t last_col,
                                          int32_t last_row);

int bresenham_next_s (bresenham_linep_t bline,
                      int32_t * col, int32_t * row);

bresenham_linep_t bresenham_from_coord (uint32_t first_col,
                                        uint32_t first_row,
                                        uint32_t last_col,
                                        uint32_t last_row);

int bresenham_next (bresenham_linep_t bline,
                    uint32_t * col, uint32_t * row);

void demolish_bresenham (bresenham_linep_t * blinehandle);

END_C_DECLARATIONS

#endif /* !BRESENHAM_H */
