/** @file tclSadie_ROI.h
 * A region of interest handling interface for tclSadie.
 * In future the tclSadie regions of interest (ROIs) might have
 * a wider range of properties, and there might be more than one type
 * of ROI, but at the moment we provide just the original SADIE
 * ROI, storing it as an image property: @sa Sadie_Index.c for
 * the mechanism used for this.
 *
 * @author University of Arizona Digital Image Analysis Lab
 * @date 1999, 2004
 * @version $Id: tclSadie_ROI.h,v 1.1 2005/03/22 20:38:22 mmunro Exp $
 */

/* This file is part of tclSadie.

   tclSadie is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   tclSadie is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with tclSadie; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.  */

#ifndef TCLSADIE_ROI_H
/** The standard guard against including the same header twice. */
#define TCLSADIE_ROI_H 1
#include "project_utilities.h"

BEGIN_C_DECLARATIONS

/** This string identifies the original SADIE ROI as an image property. */
#define ROI_PROPERTY_NAME "oldfashioned_roi_list"

extern void CREATE_ROI (IMAGE * in, const char * name, const char * dkey,
                        uint32_t xbgn, uint32_t ybgn,
                        uint32_t xend, uint32_t yend, int matrix,
                        uint32_t inc, uint32_t nlev);

END_C_DECLARATIONS

#endif /* !TCLSADIE_ROI_H */
